ClusterBlock

Enum ClusterBlock 

pub enum ClusterBlock {
    Simple(SimpleBlock),
    Group(BlockGroup),
}
A block in a Cluster, either a SimpleBlock or a BlockGroup.

This is a convenience enum to allow handling both types of blocks uniformly.

  • when reading: often we just want to iterate over all blocks in a cluster, regardless of type.
  • when writing: we may want to write a list of blocks of mixed types.

Variants



Simple(SimpleBlock)

A SimpleBlock



Group(BlockGroup)

A BlockGroup