AsyncReadElement

Trait AsyncReadElement 

pub trait AsyncReadElement: Sized + Element {
    // Provided method
    fn async_read_element<R: AsyncRead + Unpin + ?Sized>(
        header: &Header,
        r: &mut R,
    ) -> impl Future<Output = Result<Self>> { ... }
}
Available on crate feature tokio only.
Read an element from a reader provided the header asynchronously.

Provided Methods

fn async_read_element<R: AsyncRead + Unpin + ?Sized>( header: &Header, r: &mut R, ) -> impl Future<Output = Result<Self>>

Read an element from a reader provided the header.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors