pub struct AesSettingsCipherMode(pub u64);Expand description
The AES cipher mode used in the encryption.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for AesSettingsCipherMode
impl Clone for AesSettingsCipherMode
Sourcefn clone(&self) -> AesSettingsCipherMode
fn clone(&self) -> AesSettingsCipherMode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AesSettingsCipherMode
impl Debug for AesSettingsCipherMode
Sourceimpl Default for AesSettingsCipherMode
impl Default for AesSettingsCipherMode
Sourceimpl Deref for AesSettingsCipherMode
impl Deref for AesSettingsCipherMode
Sourceimpl Element for AesSettingsCipherMode
impl Element for AesSettingsCipherMode
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for AesSettingsCipherMode
impl Hash for AesSettingsCipherMode
Sourceimpl Ord for AesSettingsCipherMode
impl Ord for AesSettingsCipherMode
Sourcefn cmp(&self, other: &AesSettingsCipherMode) -> Ordering
fn cmp(&self, other: &AesSettingsCipherMode) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AesSettingsCipherMode
impl PartialEq for AesSettingsCipherMode
Sourceimpl PartialOrd for AesSettingsCipherMode
impl PartialOrd for AesSettingsCipherMode
impl Copy for AesSettingsCipherMode
impl Eq for AesSettingsCipherMode
impl StructuralPartialEq for AesSettingsCipherMode