pub struct AspectRatioType(pub u64);Expand description
Specifies the possible modifications to the aspect ratio.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for AspectRatioType
impl Clone for AspectRatioType
Sourcefn clone(&self) -> AspectRatioType
fn clone(&self) -> AspectRatioType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AspectRatioType
impl Debug for AspectRatioType
Sourceimpl Default for AspectRatioType
impl Default for AspectRatioType
Sourceimpl Deref for AspectRatioType
impl Deref for AspectRatioType
Sourceimpl Element for AspectRatioType
impl Element for AspectRatioType
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for AspectRatioType
impl Hash for AspectRatioType
Sourceimpl Ord for AspectRatioType
impl Ord for AspectRatioType
Sourcefn cmp(&self, other: &AspectRatioType) -> Ordering
fn cmp(&self, other: &AspectRatioType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AspectRatioType
impl PartialEq for AspectRatioType
Sourceimpl PartialOrd for AspectRatioType
impl PartialOrd for AspectRatioType
impl Copy for AspectRatioType
impl Eq for AspectRatioType
impl StructuralPartialEq for AspectRatioType