pub struct AttachmentLink(pub u64);Expand description
The UID of an attachment that is used by this codec.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for AttachmentLink
impl Clone for AttachmentLink
Sourcefn clone(&self) -> AttachmentLink
fn clone(&self) -> AttachmentLink
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachmentLink
impl Debug for AttachmentLink
Sourceimpl Default for AttachmentLink
impl Default for AttachmentLink
Sourceimpl Deref for AttachmentLink
impl Deref for AttachmentLink
Sourceimpl Element for AttachmentLink
impl Element for AttachmentLink
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for AttachmentLink
impl Hash for AttachmentLink
Sourceimpl Ord for AttachmentLink
impl Ord for AttachmentLink
Sourcefn cmp(&self, other: &AttachmentLink) -> Ordering
fn cmp(&self, other: &AttachmentLink) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AttachmentLink
impl PartialEq for AttachmentLink
Sourceimpl PartialOrd for AttachmentLink
impl PartialOrd for AttachmentLink
impl Copy for AttachmentLink
impl Eq for AttachmentLink
impl StructuralPartialEq for AttachmentLink