pub struct BitsPerChannel(pub u64);Expand description
Number of decoded bits per channel. A value of 0 indicates that the BitsPerChannel is unspecified.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for BitsPerChannel
impl Clone for BitsPerChannel
Sourcefn clone(&self) -> BitsPerChannel
fn clone(&self) -> BitsPerChannel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BitsPerChannel
impl Debug for BitsPerChannel
Sourceimpl Default for BitsPerChannel
impl Default for BitsPerChannel
Sourceimpl Deref for BitsPerChannel
impl Deref for BitsPerChannel
Sourceimpl Element for BitsPerChannel
impl Element for BitsPerChannel
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for BitsPerChannel
impl Hash for BitsPerChannel
Sourceimpl Ord for BitsPerChannel
impl Ord for BitsPerChannel
Sourcefn cmp(&self, other: &BitsPerChannel) -> Ordering
fn cmp(&self, other: &BitsPerChannel) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BitsPerChannel
impl PartialEq for BitsPerChannel
Sourceimpl PartialOrd for BitsPerChannel
impl PartialOrd for BitsPerChannel
impl Copy for BitsPerChannel
impl Eq for BitsPerChannel
impl StructuralPartialEq for BitsPerChannel