pub struct BlockAddIdType(pub u64);Expand description
Stores the registered identifier of the Block Additional Mapping
to define how the BlockAdditional data should be handled.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for BlockAddIdType
impl Clone for BlockAddIdType
Sourcefn clone(&self) -> BlockAddIdType
fn clone(&self) -> BlockAddIdType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockAddIdType
impl Debug for BlockAddIdType
Sourceimpl Default for BlockAddIdType
impl Default for BlockAddIdType
Sourceimpl Deref for BlockAddIdType
impl Deref for BlockAddIdType
Sourceimpl Element for BlockAddIdType
impl Element for BlockAddIdType
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for BlockAddIdType
impl Hash for BlockAddIdType
Sourceimpl Ord for BlockAddIdType
impl Ord for BlockAddIdType
Sourcefn cmp(&self, other: &BlockAddIdType) -> Ordering
fn cmp(&self, other: &BlockAddIdType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockAddIdType
impl PartialEq for BlockAddIdType
Sourceimpl PartialOrd for BlockAddIdType
impl PartialOrd for BlockAddIdType
impl Copy for BlockAddIdType
impl Eq for BlockAddIdType
impl StructuralPartialEq for BlockAddIdType