pub struct BlockAddIdValue(pub u64);Expand description
If the track format extension needs content beside frames,
the value refers to the BlockAddID ((#blockaddid-element)) value being described.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for BlockAddIdValue
impl Clone for BlockAddIdValue
Sourcefn clone(&self) -> BlockAddIdValue
fn clone(&self) -> BlockAddIdValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockAddIdValue
impl Debug for BlockAddIdValue
Sourceimpl Default for BlockAddIdValue
impl Default for BlockAddIdValue
Sourceimpl Deref for BlockAddIdValue
impl Deref for BlockAddIdValue
Sourceimpl Element for BlockAddIdValue
impl Element for BlockAddIdValue
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for BlockAddIdValue
impl Hash for BlockAddIdValue
Sourceimpl Ord for BlockAddIdValue
impl Ord for BlockAddIdValue
Sourcefn cmp(&self, other: &BlockAddIdValue) -> Ordering
fn cmp(&self, other: &BlockAddIdValue) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockAddIdValue
impl PartialEq for BlockAddIdValue
Sourceimpl PartialOrd for BlockAddIdValue
impl PartialOrd for BlockAddIdValue
impl Copy for BlockAddIdValue
impl Eq for BlockAddIdValue
impl StructuralPartialEq for BlockAddIdValue