pub struct BlockAdditionMapping {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub block_add_id_value: Option<BlockAddIdValue>,
pub block_add_id_name: Option<BlockAddIdName>,
pub block_add_id_type: BlockAddIdType,
pub block_add_id_extra_data: Option<BlockAddIdExtraData>,
}Expand description
Contains elements that extend the track format, by adding content either to each frame, with BlockAddID (BlockAddID), or to the track as a whole with BlockAddIDExtraData.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
block_add_id_value: Option<BlockAddIdValue>If the track format extension needs content beside frames, the value refers to the BlockAddID (BlockAddID), value being described. To keep MaxBlockAdditionID as low as possible, small values SHOULD be used.
block_add_id_name: Option<BlockAddIdName>A human-friendly name describing the type of BlockAdditional data, as defined by the associated Block Additional Mapping.
block_add_id_type: BlockAddIdTypeStores the registered identifier of the Block Additional Mapping to define how the BlockAdditional data should be handled. If BlockAddIDType is 0, the BlockAddIDValue and corresponding BlockAddID values MUST be 1.
block_add_id_extra_data: Option<BlockAddIdExtraData>Extra binary data that the BlockAddIDType can use to interpret the BlockAdditional data. The interpretation of the binary data depends on the BlockAddIDType value and the corresponding Block Additional Mapping.