pub struct BlockDuration(pub u64);Expand description
The duration of the Block, expressed in Track Ticks; see (#timestamp-ticks).
The BlockDuration element can be useful
at the end of a Track to define the duration of the last frame (as
there is no subsequent Block available) or when there is a break in a
track like for subtitle tracks.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for BlockDuration
impl Clone for BlockDuration
Sourcefn clone(&self) -> BlockDuration
fn clone(&self) -> BlockDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockDuration
impl Debug for BlockDuration
Sourceimpl Default for BlockDuration
impl Default for BlockDuration
Sourceimpl Deref for BlockDuration
impl Deref for BlockDuration
Sourceimpl Element for BlockDuration
impl Element for BlockDuration
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for BlockDuration
impl Hash for BlockDuration
Sourceimpl Ord for BlockDuration
impl Ord for BlockDuration
Sourcefn cmp(&self, other: &BlockDuration) -> Ordering
fn cmp(&self, other: &BlockDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockDuration
impl PartialEq for BlockDuration
Sourceimpl PartialOrd for BlockDuration
impl PartialOrd for BlockDuration
impl Copy for BlockDuration
impl Eq for BlockDuration
impl StructuralPartialEq for BlockDuration