pub struct CbSubsamplingHorz(pub u64);Expand description
The number of pixels to remove in the Cb channel for every pixel not removed horizontally.
This is additive with ChromaSubsamplingHorz.
Example: For video with 4:2:1 chroma
subsampling, the ChromaSubsamplingHorz SHOULD be set to 1, and CbSubsamplingHorz SHOULD be set to 1.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CbSubsamplingHorz
impl Clone for CbSubsamplingHorz
Sourcefn clone(&self) -> CbSubsamplingHorz
fn clone(&self) -> CbSubsamplingHorz
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CbSubsamplingHorz
impl Debug for CbSubsamplingHorz
Sourceimpl Default for CbSubsamplingHorz
impl Default for CbSubsamplingHorz
Sourceimpl Deref for CbSubsamplingHorz
impl Deref for CbSubsamplingHorz
Sourceimpl Element for CbSubsamplingHorz
impl Element for CbSubsamplingHorz
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CbSubsamplingHorz
impl Hash for CbSubsamplingHorz
Sourceimpl Ord for CbSubsamplingHorz
impl Ord for CbSubsamplingHorz
Sourcefn cmp(&self, other: &CbSubsamplingHorz) -> Ordering
fn cmp(&self, other: &CbSubsamplingHorz) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CbSubsamplingHorz
impl PartialEq for CbSubsamplingHorz
Sourceimpl PartialOrd for CbSubsamplingHorz
impl PartialOrd for CbSubsamplingHorz
impl Copy for CbSubsamplingHorz
impl Eq for CbSubsamplingHorz
impl StructuralPartialEq for CbSubsamplingHorz