pub struct CbSubsamplingVert(pub u64);Expand description
The number of pixels to remove in the Cb channel for every pixel not removed vertically.
This is additive with ChromaSubsamplingVert.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CbSubsamplingVert
impl Clone for CbSubsamplingVert
Sourcefn clone(&self) -> CbSubsamplingVert
fn clone(&self) -> CbSubsamplingVert
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CbSubsamplingVert
impl Debug for CbSubsamplingVert
Sourceimpl Default for CbSubsamplingVert
impl Default for CbSubsamplingVert
Sourceimpl Deref for CbSubsamplingVert
impl Deref for CbSubsamplingVert
Sourceimpl Element for CbSubsamplingVert
impl Element for CbSubsamplingVert
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CbSubsamplingVert
impl Hash for CbSubsamplingVert
Sourceimpl Ord for CbSubsamplingVert
impl Ord for CbSubsamplingVert
Sourcefn cmp(&self, other: &CbSubsamplingVert) -> Ordering
fn cmp(&self, other: &CbSubsamplingVert) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CbSubsamplingVert
impl PartialEq for CbSubsamplingVert
Sourceimpl PartialOrd for CbSubsamplingVert
impl PartialOrd for CbSubsamplingVert
impl Copy for CbSubsamplingVert
impl Eq for CbSubsamplingVert
impl StructuralPartialEq for CbSubsamplingVert