pub struct Channels(pub u64);Expand description
Numbers of channels in the track.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for Channels
impl Element for Channels
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for Channels
impl Ord for Channels
Sourceimpl PartialOrd for Channels
impl PartialOrd for Channels
impl Copy for Channels
impl Eq for Channels
impl StructuralPartialEq for Channels