pub struct ChapProcessCodecId(pub u64);Expand description
Contains the type of the codec used for processing.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapProcessCodecId
impl Clone for ChapProcessCodecId
Sourcefn clone(&self) -> ChapProcessCodecId
fn clone(&self) -> ChapProcessCodecId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapProcessCodecId
impl Debug for ChapProcessCodecId
Sourceimpl Default for ChapProcessCodecId
impl Default for ChapProcessCodecId
Sourceimpl Deref for ChapProcessCodecId
impl Deref for ChapProcessCodecId
Sourceimpl Element for ChapProcessCodecId
impl Element for ChapProcessCodecId
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ChapProcessCodecId
impl Hash for ChapProcessCodecId
Sourceimpl Ord for ChapProcessCodecId
impl Ord for ChapProcessCodecId
Sourcefn cmp(&self, other: &ChapProcessCodecId) -> Ordering
fn cmp(&self, other: &ChapProcessCodecId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapProcessCodecId
impl PartialEq for ChapProcessCodecId
Sourceimpl PartialOrd for ChapProcessCodecId
impl PartialOrd for ChapProcessCodecId
impl Copy for ChapProcessCodecId
impl Eq for ChapProcessCodecId
impl StructuralPartialEq for ChapProcessCodecId