pub struct ChapProcessTime(pub u64);Expand description
Defines when the process command SHOULD be handled.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapProcessTime
impl Clone for ChapProcessTime
Sourcefn clone(&self) -> ChapProcessTime
fn clone(&self) -> ChapProcessTime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapProcessTime
impl Debug for ChapProcessTime
Sourceimpl Default for ChapProcessTime
impl Default for ChapProcessTime
Sourceimpl Deref for ChapProcessTime
impl Deref for ChapProcessTime
Sourceimpl Element for ChapProcessTime
impl Element for ChapProcessTime
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapProcessTime
impl Hash for ChapProcessTime
Sourceimpl Ord for ChapProcessTime
impl Ord for ChapProcessTime
Sourcefn cmp(&self, other: &ChapProcessTime) -> Ordering
fn cmp(&self, other: &ChapProcessTime) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapProcessTime
impl PartialEq for ChapProcessTime
Sourceimpl PartialOrd for ChapProcessTime
impl PartialOrd for ChapProcessTime
impl Copy for ChapProcessTime
impl Eq for ChapProcessTime
impl StructuralPartialEq for ChapProcessTime