pub struct ChapterFlagEnabled(pub u64);Expand description
Set to 1 if the chapter is enabled. It can be enabled/disabled by a Control Track.
When disabled, the movie SHOULD skip all the content between the TimeStart and TimeEnd of this chapter; see (#chapter-flags) on Chapter flags.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterFlagEnabled
impl Clone for ChapterFlagEnabled
Sourcefn clone(&self) -> ChapterFlagEnabled
fn clone(&self) -> ChapterFlagEnabled
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterFlagEnabled
impl Debug for ChapterFlagEnabled
Sourceimpl Default for ChapterFlagEnabled
impl Default for ChapterFlagEnabled
Sourceimpl Deref for ChapterFlagEnabled
impl Deref for ChapterFlagEnabled
Sourceimpl Element for ChapterFlagEnabled
impl Element for ChapterFlagEnabled
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterFlagEnabled
impl Hash for ChapterFlagEnabled
Sourceimpl Ord for ChapterFlagEnabled
impl Ord for ChapterFlagEnabled
Sourcefn cmp(&self, other: &ChapterFlagEnabled) -> Ordering
fn cmp(&self, other: &ChapterFlagEnabled) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterFlagEnabled
impl PartialEq for ChapterFlagEnabled
Sourceimpl PartialOrd for ChapterFlagEnabled
impl PartialOrd for ChapterFlagEnabled
impl Copy for ChapterFlagEnabled
impl Eq for ChapterFlagEnabled
impl StructuralPartialEq for ChapterFlagEnabled