pub struct ChapterFlagHidden(pub u64);Expand description
Set to 1 if a chapter is hidden.
Hidden chapters SHOULD NOT be available to the user interface
(but still be available to Control Tracks; see (#chapterflaghidden) on Chapter flags).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterFlagHidden
impl Clone for ChapterFlagHidden
Sourcefn clone(&self) -> ChapterFlagHidden
fn clone(&self) -> ChapterFlagHidden
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterFlagHidden
impl Debug for ChapterFlagHidden
Sourceimpl Default for ChapterFlagHidden
impl Default for ChapterFlagHidden
Sourceimpl Deref for ChapterFlagHidden
impl Deref for ChapterFlagHidden
Sourceimpl Element for ChapterFlagHidden
impl Element for ChapterFlagHidden
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterFlagHidden
impl Hash for ChapterFlagHidden
Sourceimpl Ord for ChapterFlagHidden
impl Ord for ChapterFlagHidden
Sourcefn cmp(&self, other: &ChapterFlagHidden) -> Ordering
fn cmp(&self, other: &ChapterFlagHidden) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterFlagHidden
impl PartialEq for ChapterFlagHidden
Sourceimpl PartialOrd for ChapterFlagHidden
impl PartialOrd for ChapterFlagHidden
impl Copy for ChapterFlagHidden
impl Eq for ChapterFlagHidden
impl StructuralPartialEq for ChapterFlagHidden