pub struct ChapterPhysicalEquiv(pub u64);Expand description
Specifies the physical equivalent of this ChapterAtom, e.g., “DVD” (60) or “SIDE” (50);
see (#physical-types) for a complete list of values.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterPhysicalEquiv
impl Clone for ChapterPhysicalEquiv
Sourcefn clone(&self) -> ChapterPhysicalEquiv
fn clone(&self) -> ChapterPhysicalEquiv
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterPhysicalEquiv
impl Debug for ChapterPhysicalEquiv
Sourceimpl Default for ChapterPhysicalEquiv
impl Default for ChapterPhysicalEquiv
Sourceimpl Deref for ChapterPhysicalEquiv
impl Deref for ChapterPhysicalEquiv
Sourceimpl Element for ChapterPhysicalEquiv
impl Element for ChapterPhysicalEquiv
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterPhysicalEquiv
impl Hash for ChapterPhysicalEquiv
Sourceimpl Ord for ChapterPhysicalEquiv
impl Ord for ChapterPhysicalEquiv
Sourcefn cmp(&self, other: &ChapterPhysicalEquiv) -> Ordering
fn cmp(&self, other: &ChapterPhysicalEquiv) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterPhysicalEquiv
impl PartialEq for ChapterPhysicalEquiv
Sourceimpl PartialOrd for ChapterPhysicalEquiv
impl PartialOrd for ChapterPhysicalEquiv
impl Copy for ChapterPhysicalEquiv
impl Eq for ChapterPhysicalEquiv
impl StructuralPartialEq for ChapterPhysicalEquiv