pub struct ChapterSegmentEditionUid(pub u64);Expand description
The EditionUID to play from the Segment linked in ChapterSegmentUUID.
If ChapterSegmentEditionUID is undeclared, then no Edition of the Linked Segment is used; see (#medium-linking) on Medium-Linking Segments.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterSegmentEditionUid
impl Clone for ChapterSegmentEditionUid
Sourcefn clone(&self) -> ChapterSegmentEditionUid
fn clone(&self) -> ChapterSegmentEditionUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterSegmentEditionUid
impl Debug for ChapterSegmentEditionUid
Sourceimpl Default for ChapterSegmentEditionUid
impl Default for ChapterSegmentEditionUid
Sourceimpl Deref for ChapterSegmentEditionUid
impl Deref for ChapterSegmentEditionUid
Sourceimpl Element for ChapterSegmentEditionUid
impl Element for ChapterSegmentEditionUid
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterSegmentEditionUid
impl Hash for ChapterSegmentEditionUid
Sourceimpl Ord for ChapterSegmentEditionUid
impl Ord for ChapterSegmentEditionUid
Sourcefn cmp(&self, other: &ChapterSegmentEditionUid) -> Ordering
fn cmp(&self, other: &ChapterSegmentEditionUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterSegmentEditionUid
impl PartialEq for ChapterSegmentEditionUid
Sourceimpl PartialOrd for ChapterSegmentEditionUid
impl PartialOrd for ChapterSegmentEditionUid
impl Copy for ChapterSegmentEditionUid
impl Eq for ChapterSegmentEditionUid
impl StructuralPartialEq for ChapterSegmentEditionUid