pub struct ChapterSkipType(pub u64);Expand description
Indicates what type of content the ChapterAtom contains and might be skipped.
It can be used to automatically skip content based on the type.
If a ChapterAtom is inside a ChapterAtom that has a ChapterSkipType set, it
MUST NOT have a ChapterSkipType or have a ChapterSkipType with the same value as it’s parent ChapterAtom.
If the ChapterAtom doesn’t contain a ChapterTimeEnd, the value of the ChapterSkipType is only valid until the next ChapterAtom with a ChapterSkipType value or the end of the file.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterSkipType
impl Clone for ChapterSkipType
Sourcefn clone(&self) -> ChapterSkipType
fn clone(&self) -> ChapterSkipType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterSkipType
impl Debug for ChapterSkipType
Sourceimpl Default for ChapterSkipType
impl Default for ChapterSkipType
Sourceimpl Deref for ChapterSkipType
impl Deref for ChapterSkipType
Sourceimpl Element for ChapterSkipType
impl Element for ChapterSkipType
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterSkipType
impl Hash for ChapterSkipType
Sourceimpl Ord for ChapterSkipType
impl Ord for ChapterSkipType
Sourcefn cmp(&self, other: &ChapterSkipType) -> Ordering
fn cmp(&self, other: &ChapterSkipType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterSkipType
impl PartialEq for ChapterSkipType
Sourceimpl PartialOrd for ChapterSkipType
impl PartialOrd for ChapterSkipType
impl Copy for ChapterSkipType
impl Eq for ChapterSkipType
impl StructuralPartialEq for ChapterSkipType