pub struct ChapterTimeEnd(pub u64);Expand description
Timestamp of the end of Chapter (timestamp excluded), expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks).
The value MUST be greater than or equal to the ChapterTimeStart of the same ChapterAtom.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterTimeEnd
impl Clone for ChapterTimeEnd
Sourcefn clone(&self) -> ChapterTimeEnd
fn clone(&self) -> ChapterTimeEnd
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterTimeEnd
impl Debug for ChapterTimeEnd
Sourceimpl Default for ChapterTimeEnd
impl Default for ChapterTimeEnd
Sourceimpl Deref for ChapterTimeEnd
impl Deref for ChapterTimeEnd
Sourceimpl Element for ChapterTimeEnd
impl Element for ChapterTimeEnd
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterTimeEnd
impl Hash for ChapterTimeEnd
Sourceimpl Ord for ChapterTimeEnd
impl Ord for ChapterTimeEnd
Sourcefn cmp(&self, other: &ChapterTimeEnd) -> Ordering
fn cmp(&self, other: &ChapterTimeEnd) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterTimeEnd
impl PartialEq for ChapterTimeEnd
Sourceimpl PartialOrd for ChapterTimeEnd
impl PartialOrd for ChapterTimeEnd
impl Copy for ChapterTimeEnd
impl Eq for ChapterTimeEnd
impl StructuralPartialEq for ChapterTimeEnd