pub struct ChapterTimeStart(pub u64);Expand description
Timestamp of the start of Chapter, expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterTimeStart
impl Clone for ChapterTimeStart
Sourcefn clone(&self) -> ChapterTimeStart
fn clone(&self) -> ChapterTimeStart
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterTimeStart
impl Debug for ChapterTimeStart
Sourceimpl Default for ChapterTimeStart
impl Default for ChapterTimeStart
Sourceimpl Deref for ChapterTimeStart
impl Deref for ChapterTimeStart
Sourceimpl Element for ChapterTimeStart
impl Element for ChapterTimeStart
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterTimeStart
impl Hash for ChapterTimeStart
Sourceimpl Ord for ChapterTimeStart
impl Ord for ChapterTimeStart
Sourcefn cmp(&self, other: &ChapterTimeStart) -> Ordering
fn cmp(&self, other: &ChapterTimeStart) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterTimeStart
impl PartialEq for ChapterTimeStart
Sourceimpl PartialOrd for ChapterTimeStart
impl PartialOrd for ChapterTimeStart
impl Copy for ChapterTimeStart
impl Eq for ChapterTimeStart
impl StructuralPartialEq for ChapterTimeStart