pub struct ChapterTranslate {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub chapter_translate_id: ChapterTranslateId,
pub chapter_translate_codec: ChapterTranslateCodec,
pub chapter_translate_edition_uid: Vec<ChapterTranslateEditionUid>,
}Expand description
The mapping between this Segment and a segment value in the given Chapter Codec. Chapter Codec may need to address different segments, but they may not know of the way to identify such segment when stored in Matroska. This element and its child elements add a way to map the internal segments known to the Chapter Codec to the Segment IDs in Matroska. This allows remuxing a file with Chapter Codec without changing the content of the codec data, just the Segment mapping.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
chapter_translate_id: ChapterTranslateIdThe binary value used to represent this Segment in the chapter codec data. The format depends on the ChapProcessCodecID used; see ChapProcessCodecID.
chapter_translate_codec: ChapterTranslateCodecThis ChapterTranslate applies to this chapter codec of the given chapter edition(s); see ChapProcessCodecID.
- 0 - Matroska Script,
- 1 - DVD-menu
chapter_translate_edition_uid: Vec<ChapterTranslateEditionUid>Specify a chapter edition UID on which this ChapterTranslate applies. When no ChapterTranslateEditionUID is specified in the ChapterTranslate, the ChapterTranslate applies to all chapter editions found in the Segment using the given ChapterTranslateCodec.