pub struct ChapterTranslateCodec(pub u64);Expand description
Applies to the chapter codec of the given chapter edition(s); see (#chapprocesscodecid-element).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterTranslateCodec
impl Clone for ChapterTranslateCodec
Sourcefn clone(&self) -> ChapterTranslateCodec
fn clone(&self) -> ChapterTranslateCodec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterTranslateCodec
impl Debug for ChapterTranslateCodec
Sourceimpl Default for ChapterTranslateCodec
impl Default for ChapterTranslateCodec
Sourceimpl Deref for ChapterTranslateCodec
impl Deref for ChapterTranslateCodec
Sourceimpl Element for ChapterTranslateCodec
impl Element for ChapterTranslateCodec
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterTranslateCodec
impl Hash for ChapterTranslateCodec
Sourceimpl Ord for ChapterTranslateCodec
impl Ord for ChapterTranslateCodec
Sourcefn cmp(&self, other: &ChapterTranslateCodec) -> Ordering
fn cmp(&self, other: &ChapterTranslateCodec) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterTranslateCodec
impl PartialEq for ChapterTranslateCodec
Sourceimpl PartialOrd for ChapterTranslateCodec
impl PartialOrd for ChapterTranslateCodec
impl Copy for ChapterTranslateCodec
impl Eq for ChapterTranslateCodec
impl StructuralPartialEq for ChapterTranslateCodec