pub struct ChapterTranslateEditionUid(pub u64);Expand description
Specifies a chapter edition UID to which this ChapterTranslate applies.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterTranslateEditionUid
impl Clone for ChapterTranslateEditionUid
Sourcefn clone(&self) -> ChapterTranslateEditionUid
fn clone(&self) -> ChapterTranslateEditionUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterTranslateEditionUid
impl Debug for ChapterTranslateEditionUid
Sourceimpl Default for ChapterTranslateEditionUid
impl Default for ChapterTranslateEditionUid
Sourceimpl Deref for ChapterTranslateEditionUid
impl Deref for ChapterTranslateEditionUid
Sourceimpl Element for ChapterTranslateEditionUid
impl Element for ChapterTranslateEditionUid
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterTranslateEditionUid
impl Hash for ChapterTranslateEditionUid
Sourceimpl Ord for ChapterTranslateEditionUid
impl Ord for ChapterTranslateEditionUid
Sourcefn cmp(&self, other: &ChapterTranslateEditionUid) -> Ordering
fn cmp(&self, other: &ChapterTranslateEditionUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ChapterTranslateEditionUid
impl PartialOrd for ChapterTranslateEditionUid
impl Copy for ChapterTranslateEditionUid
impl Eq for ChapterTranslateEditionUid
impl StructuralPartialEq for ChapterTranslateEditionUid