pub struct ChapterUid(pub u64);Expand description
A UID that identifies the Chapter.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChapterUid
impl Clone for ChapterUid
Sourcefn clone(&self) -> ChapterUid
fn clone(&self) -> ChapterUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChapterUid
impl Debug for ChapterUid
Sourceimpl Default for ChapterUid
impl Default for ChapterUid
Sourceimpl Deref for ChapterUid
impl Deref for ChapterUid
Sourceimpl Element for ChapterUid
impl Element for ChapterUid
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChapterUid
impl Hash for ChapterUid
Sourceimpl Ord for ChapterUid
impl Ord for ChapterUid
Sourcefn cmp(&self, other: &ChapterUid) -> Ordering
fn cmp(&self, other: &ChapterUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChapterUid
impl PartialEq for ChapterUid
Sourceimpl PartialOrd for ChapterUid
impl PartialOrd for ChapterUid
impl Copy for ChapterUid
impl Eq for ChapterUid
impl StructuralPartialEq for ChapterUid