pub struct Chapters {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub edition_entry: Vec<EditionEntry>,
}Expand description
A system to define basic menus and partition data. For more detailed information, look at the Chapters explanation in chapters.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
edition_entry: Vec<EditionEntry>Contains all information about a Segment edition.