pub struct ChromaSitingVert(pub u64);Expand description
How chroma is subsampled vertically.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChromaSitingVert
impl Clone for ChromaSitingVert
Sourcefn clone(&self) -> ChromaSitingVert
fn clone(&self) -> ChromaSitingVert
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChromaSitingVert
impl Debug for ChromaSitingVert
Sourceimpl Default for ChromaSitingVert
impl Default for ChromaSitingVert
Sourceimpl Deref for ChromaSitingVert
impl Deref for ChromaSitingVert
Sourceimpl Element for ChromaSitingVert
impl Element for ChromaSitingVert
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChromaSitingVert
impl Hash for ChromaSitingVert
Sourceimpl Ord for ChromaSitingVert
impl Ord for ChromaSitingVert
Sourcefn cmp(&self, other: &ChromaSitingVert) -> Ordering
fn cmp(&self, other: &ChromaSitingVert) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChromaSitingVert
impl PartialEq for ChromaSitingVert
Sourceimpl PartialOrd for ChromaSitingVert
impl PartialOrd for ChromaSitingVert
impl Copy for ChromaSitingVert
impl Eq for ChromaSitingVert
impl StructuralPartialEq for ChromaSitingVert