pub struct ChromaSubsamplingHorz(pub u64);Expand description
The number of pixels to remove in the Cr and Cb channels for every pixel not removed horizontally. Example: For video with 4:2:0 chroma subsampling, the ChromaSubsamplingHorz
SHOULD be set to 1.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChromaSubsamplingHorz
impl Clone for ChromaSubsamplingHorz
Sourcefn clone(&self) -> ChromaSubsamplingHorz
fn clone(&self) -> ChromaSubsamplingHorz
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChromaSubsamplingHorz
impl Debug for ChromaSubsamplingHorz
Sourceimpl Default for ChromaSubsamplingHorz
impl Default for ChromaSubsamplingHorz
Sourceimpl Deref for ChromaSubsamplingHorz
impl Deref for ChromaSubsamplingHorz
Sourceimpl Element for ChromaSubsamplingHorz
impl Element for ChromaSubsamplingHorz
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChromaSubsamplingHorz
impl Hash for ChromaSubsamplingHorz
Sourceimpl Ord for ChromaSubsamplingHorz
impl Ord for ChromaSubsamplingHorz
Sourcefn cmp(&self, other: &ChromaSubsamplingHorz) -> Ordering
fn cmp(&self, other: &ChromaSubsamplingHorz) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChromaSubsamplingHorz
impl PartialEq for ChromaSubsamplingHorz
Sourceimpl PartialOrd for ChromaSubsamplingHorz
impl PartialOrd for ChromaSubsamplingHorz
impl Copy for ChromaSubsamplingHorz
impl Eq for ChromaSubsamplingHorz
impl StructuralPartialEq for ChromaSubsamplingHorz