pub struct ChromaSubsamplingVert(pub u64);Expand description
The number of pixels to remove in the Cr and Cb channels for every pixel not removed vertically.
Example: For video with 4:2:0 chroma subsampling, the ChromaSubsamplingVert
SHOULD be set to 1.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ChromaSubsamplingVert
impl Clone for ChromaSubsamplingVert
Sourcefn clone(&self) -> ChromaSubsamplingVert
fn clone(&self) -> ChromaSubsamplingVert
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChromaSubsamplingVert
impl Debug for ChromaSubsamplingVert
Sourceimpl Default for ChromaSubsamplingVert
impl Default for ChromaSubsamplingVert
Sourceimpl Deref for ChromaSubsamplingVert
impl Deref for ChromaSubsamplingVert
Sourceimpl Element for ChromaSubsamplingVert
impl Element for ChromaSubsamplingVert
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ChromaSubsamplingVert
impl Hash for ChromaSubsamplingVert
Sourceimpl Ord for ChromaSubsamplingVert
impl Ord for ChromaSubsamplingVert
Sourcefn cmp(&self, other: &ChromaSubsamplingVert) -> Ordering
fn cmp(&self, other: &ChromaSubsamplingVert) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChromaSubsamplingVert
impl PartialEq for ChromaSubsamplingVert
Sourceimpl PartialOrd for ChromaSubsamplingVert
impl PartialOrd for ChromaSubsamplingVert
impl Copy for ChromaSubsamplingVert
impl Eq for ChromaSubsamplingVert
impl StructuralPartialEq for ChromaSubsamplingVert