Cluster

Struct Cluster 

pub struct Cluster {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub timestamp: Timestamp,
    pub position: Option<Position>,
    pub prev_size: Option<PrevSize>,
    pub blocks: Vec<ClusterBlock>,
}
The Top-Level Element containing the (monolithic) Block structure.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

timestamp: Timestamp

Absolute timestamp of the cluster, expressed in Segment Ticks which is based on TimestampScale; see timestamp-ticks. This element SHOULD be the first child element of the Cluster it belongs to, or the second if that Cluster contains a CRC-32 element (crc-32).

position: Option<Position>

The Segment Position of the Cluster in the Segment (0 in live streams). It might help to resynchronise offset on damaged streams.

prev_size: Option<PrevSize>

Size of the previous Cluster, in octets. Can be useful for backward playing.

blocks: Vec<ClusterBlock>

One or more blocks of data (see Block and SimpleBlock) and their associated data (see BlockGroup).

Implementations

Source

impl Cluster

pub fn frames(&self) -> impl Iterator<Item = Result<Frame<'_>>> + '_

frames in the cluster.