pub struct CodecDecodeAll(pub u64);Expand description
Set to 1 if the codec can decode potentially damaged data.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CodecDecodeAll
impl Clone for CodecDecodeAll
Sourcefn clone(&self) -> CodecDecodeAll
fn clone(&self) -> CodecDecodeAll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodecDecodeAll
impl Debug for CodecDecodeAll
Sourceimpl Default for CodecDecodeAll
impl Default for CodecDecodeAll
Sourceimpl Deref for CodecDecodeAll
impl Deref for CodecDecodeAll
Sourceimpl Element for CodecDecodeAll
impl Element for CodecDecodeAll
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CodecDecodeAll
impl Hash for CodecDecodeAll
Sourceimpl Ord for CodecDecodeAll
impl Ord for CodecDecodeAll
Sourcefn cmp(&self, other: &CodecDecodeAll) -> Ordering
fn cmp(&self, other: &CodecDecodeAll) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CodecDecodeAll
impl PartialEq for CodecDecodeAll
Sourceimpl PartialOrd for CodecDecodeAll
impl PartialOrd for CodecDecodeAll
impl Copy for CodecDecodeAll
impl Eq for CodecDecodeAll
impl StructuralPartialEq for CodecDecodeAll