pub struct CodecDelay(pub u64);Expand description
The built-in delay for the codec, expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks).
It represents the number of codec samples that will be discarded by the decoder during playback.
This timestamp value MUST be subtracted from each frame timestamp in order to get the timestamp that will be actually played.
The value SHOULD be small so the muxing of tracks with the same actual timestamp are in the same Cluster.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CodecDelay
impl Clone for CodecDelay
Sourcefn clone(&self) -> CodecDelay
fn clone(&self) -> CodecDelay
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodecDelay
impl Debug for CodecDelay
Sourceimpl Default for CodecDelay
impl Default for CodecDelay
Sourceimpl Deref for CodecDelay
impl Deref for CodecDelay
Sourceimpl Element for CodecDelay
impl Element for CodecDelay
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for CodecDelay
impl Hash for CodecDelay
Sourceimpl Ord for CodecDelay
impl Ord for CodecDelay
Sourcefn cmp(&self, other: &CodecDelay) -> Ordering
fn cmp(&self, other: &CodecDelay) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CodecDelay
impl PartialEq for CodecDelay
Sourceimpl PartialOrd for CodecDelay
impl PartialOrd for CodecDelay
impl Copy for CodecDelay
impl Eq for CodecDelay
impl StructuralPartialEq for CodecDelay