pub struct ContentCompAlgo(pub u64);Expand description
The compression algorithm used.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentCompAlgo
impl Clone for ContentCompAlgo
Sourcefn clone(&self) -> ContentCompAlgo
fn clone(&self) -> ContentCompAlgo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentCompAlgo
impl Debug for ContentCompAlgo
Sourceimpl Default for ContentCompAlgo
impl Default for ContentCompAlgo
Sourceimpl Deref for ContentCompAlgo
impl Deref for ContentCompAlgo
Sourceimpl Element for ContentCompAlgo
impl Element for ContentCompAlgo
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ContentCompAlgo
impl Hash for ContentCompAlgo
Sourceimpl Ord for ContentCompAlgo
impl Ord for ContentCompAlgo
Sourcefn cmp(&self, other: &ContentCompAlgo) -> Ordering
fn cmp(&self, other: &ContentCompAlgo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentCompAlgo
impl PartialEq for ContentCompAlgo
Sourceimpl PartialOrd for ContentCompAlgo
impl PartialOrd for ContentCompAlgo
impl Copy for ContentCompAlgo
impl Eq for ContentCompAlgo
impl StructuralPartialEq for ContentCompAlgo