pub struct ContentEncAlgo(pub u64);Expand description
The encryption algorithm used.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentEncAlgo
impl Clone for ContentEncAlgo
Sourcefn clone(&self) -> ContentEncAlgo
fn clone(&self) -> ContentEncAlgo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentEncAlgo
impl Debug for ContentEncAlgo
Sourceimpl Default for ContentEncAlgo
impl Default for ContentEncAlgo
Sourceimpl Deref for ContentEncAlgo
impl Deref for ContentEncAlgo
Sourceimpl Element for ContentEncAlgo
impl Element for ContentEncAlgo
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ContentEncAlgo
impl Hash for ContentEncAlgo
Sourceimpl Ord for ContentEncAlgo
impl Ord for ContentEncAlgo
Sourcefn cmp(&self, other: &ContentEncAlgo) -> Ordering
fn cmp(&self, other: &ContentEncAlgo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentEncAlgo
impl PartialEq for ContentEncAlgo
Sourceimpl PartialOrd for ContentEncAlgo
impl PartialOrd for ContentEncAlgo
impl Copy for ContentEncAlgo
impl Eq for ContentEncAlgo
impl StructuralPartialEq for ContentEncAlgo