pub struct ContentEncodingOrder(pub u64);Expand description
Defines the order to apply each ContentEncoding of the ContentEncodings.
The decoder/demuxer MUST start with the ContentEncoding with the highest ContentEncodingOrder and work its way down to the ContentEncoding with the lowest ContentEncodingOrder.
This value MUST be unique for each ContentEncoding found in the ContentEncodings of this TrackEntry.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentEncodingOrder
impl Clone for ContentEncodingOrder
Sourcefn clone(&self) -> ContentEncodingOrder
fn clone(&self) -> ContentEncodingOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentEncodingOrder
impl Debug for ContentEncodingOrder
Sourceimpl Default for ContentEncodingOrder
impl Default for ContentEncodingOrder
Sourceimpl Deref for ContentEncodingOrder
impl Deref for ContentEncodingOrder
Sourceimpl Element for ContentEncodingOrder
impl Element for ContentEncodingOrder
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ContentEncodingOrder
impl Hash for ContentEncodingOrder
Sourceimpl Ord for ContentEncodingOrder
impl Ord for ContentEncodingOrder
Sourcefn cmp(&self, other: &ContentEncodingOrder) -> Ordering
fn cmp(&self, other: &ContentEncodingOrder) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentEncodingOrder
impl PartialEq for ContentEncodingOrder
Sourceimpl PartialOrd for ContentEncodingOrder
impl PartialOrd for ContentEncodingOrder
impl Copy for ContentEncodingOrder
impl Eq for ContentEncodingOrder
impl StructuralPartialEq for ContentEncodingOrder