pub struct ContentEncodingType(pub u64);Expand description
A value describing the kind of transformation that is applied.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentEncodingType
impl Clone for ContentEncodingType
Sourcefn clone(&self) -> ContentEncodingType
fn clone(&self) -> ContentEncodingType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentEncodingType
impl Debug for ContentEncodingType
Sourceimpl Default for ContentEncodingType
impl Default for ContentEncodingType
Sourceimpl Deref for ContentEncodingType
impl Deref for ContentEncodingType
Sourceimpl Element for ContentEncodingType
impl Element for ContentEncodingType
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ContentEncodingType
impl Hash for ContentEncodingType
Sourceimpl Ord for ContentEncodingType
impl Ord for ContentEncodingType
Sourcefn cmp(&self, other: &ContentEncodingType) -> Ordering
fn cmp(&self, other: &ContentEncodingType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentEncodingType
impl PartialEq for ContentEncodingType
Sourceimpl PartialOrd for ContentEncodingType
impl PartialOrd for ContentEncodingType
impl Copy for ContentEncodingType
impl Eq for ContentEncodingType
impl StructuralPartialEq for ContentEncodingType