pub struct ContentEncodings {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub content_encoding: Vec<ContentEncoding>,
}Expand description
Settings for several content encoding mechanisms like compression or encryption.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
content_encoding: Vec<ContentEncoding>Settings for one content encoding like compression or encryption.