pub struct ContentSigAlgo(pub u64);Expand description
The algorithm used for the signature.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentSigAlgo
impl Clone for ContentSigAlgo
Sourcefn clone(&self) -> ContentSigAlgo
fn clone(&self) -> ContentSigAlgo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentSigAlgo
impl Debug for ContentSigAlgo
Sourceimpl Default for ContentSigAlgo
impl Default for ContentSigAlgo
Sourceimpl Deref for ContentSigAlgo
impl Deref for ContentSigAlgo
Sourceimpl Element for ContentSigAlgo
impl Element for ContentSigAlgo
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ContentSigAlgo
impl Hash for ContentSigAlgo
Sourceimpl Ord for ContentSigAlgo
impl Ord for ContentSigAlgo
Sourcefn cmp(&self, other: &ContentSigAlgo) -> Ordering
fn cmp(&self, other: &ContentSigAlgo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentSigAlgo
impl PartialEq for ContentSigAlgo
Sourceimpl PartialOrd for ContentSigAlgo
impl PartialOrd for ContentSigAlgo
impl Copy for ContentSigAlgo
impl Eq for ContentSigAlgo
impl StructuralPartialEq for ContentSigAlgo