pub struct ContentSigHashAlgo(pub u64);Expand description
The hash algorithm used for the signature.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ContentSigHashAlgo
impl Clone for ContentSigHashAlgo
Sourcefn clone(&self) -> ContentSigHashAlgo
fn clone(&self) -> ContentSigHashAlgo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentSigHashAlgo
impl Debug for ContentSigHashAlgo
Sourceimpl Default for ContentSigHashAlgo
impl Default for ContentSigHashAlgo
Sourceimpl Deref for ContentSigHashAlgo
impl Deref for ContentSigHashAlgo
Sourceimpl Element for ContentSigHashAlgo
impl Element for ContentSigHashAlgo
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ContentSigHashAlgo
impl Hash for ContentSigHashAlgo
Sourceimpl Ord for ContentSigHashAlgo
impl Ord for ContentSigHashAlgo
Sourcefn cmp(&self, other: &ContentSigHashAlgo) -> Ordering
fn cmp(&self, other: &ContentSigHashAlgo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ContentSigHashAlgo
impl PartialEq for ContentSigHashAlgo
Sourceimpl PartialOrd for ContentSigHashAlgo
impl PartialOrd for ContentSigHashAlgo
impl Copy for ContentSigHashAlgo
impl Eq for ContentSigHashAlgo
impl StructuralPartialEq for ContentSigHashAlgo