pub struct Crc32(pub u32);Expand description
CRC-32 element, used for integrity checking. The CRC-32 is stored as a little-endian u32.
Note:
- This element can be included in any Master element to provide a CRC-32 checksum of the element’s data.
- It has to be the first element in the Master element’s body if it is present.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Element for Crc32
impl Element for Crc32
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
impl Copy for Crc32
impl Eq for Crc32
impl StructuralPartialEq for Crc32