pub struct CueBlockNumber(pub u64);Expand description
Number of the Block in the specified Cluster.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueBlockNumber
impl Clone for CueBlockNumber
Sourcefn clone(&self) -> CueBlockNumber
fn clone(&self) -> CueBlockNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueBlockNumber
impl Debug for CueBlockNumber
Sourceimpl Default for CueBlockNumber
impl Default for CueBlockNumber
Sourceimpl Deref for CueBlockNumber
impl Deref for CueBlockNumber
Sourceimpl Element for CueBlockNumber
impl Element for CueBlockNumber
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CueBlockNumber
impl Hash for CueBlockNumber
Sourceimpl Ord for CueBlockNumber
impl Ord for CueBlockNumber
Sourcefn cmp(&self, other: &CueBlockNumber) -> Ordering
fn cmp(&self, other: &CueBlockNumber) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueBlockNumber
impl PartialEq for CueBlockNumber
Sourceimpl PartialOrd for CueBlockNumber
impl PartialOrd for CueBlockNumber
impl Copy for CueBlockNumber
impl Eq for CueBlockNumber
impl StructuralPartialEq for CueBlockNumber