pub struct CueClusterPosition(pub u64);Expand description
The Segment Position ((#segment-position)) of the Cluster containing the associated Block.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueClusterPosition
impl Clone for CueClusterPosition
Sourcefn clone(&self) -> CueClusterPosition
fn clone(&self) -> CueClusterPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueClusterPosition
impl Debug for CueClusterPosition
Sourceimpl Default for CueClusterPosition
impl Default for CueClusterPosition
Sourceimpl Deref for CueClusterPosition
impl Deref for CueClusterPosition
Sourceimpl Element for CueClusterPosition
impl Element for CueClusterPosition
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CueClusterPosition
impl Hash for CueClusterPosition
Sourceimpl Ord for CueClusterPosition
impl Ord for CueClusterPosition
Sourcefn cmp(&self, other: &CueClusterPosition) -> Ordering
fn cmp(&self, other: &CueClusterPosition) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueClusterPosition
impl PartialEq for CueClusterPosition
Sourceimpl PartialOrd for CueClusterPosition
impl PartialOrd for CueClusterPosition
impl Copy for CueClusterPosition
impl Eq for CueClusterPosition
impl StructuralPartialEq for CueClusterPosition