pub struct CueCodecState(pub u64);Expand description
The Segment Position ((#segment-position)) of the
Codec State corresponding to this Cues element. 0 means that the
data is taken from the initial TrackEntry.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueCodecState
impl Clone for CueCodecState
Sourcefn clone(&self) -> CueCodecState
fn clone(&self) -> CueCodecState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueCodecState
impl Debug for CueCodecState
Sourceimpl Default for CueCodecState
impl Default for CueCodecState
Sourceimpl Deref for CueCodecState
impl Deref for CueCodecState
Sourceimpl Element for CueCodecState
impl Element for CueCodecState
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for CueCodecState
impl Hash for CueCodecState
Sourceimpl Ord for CueCodecState
impl Ord for CueCodecState
Sourcefn cmp(&self, other: &CueCodecState) -> Ordering
fn cmp(&self, other: &CueCodecState) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueCodecState
impl PartialEq for CueCodecState
Sourceimpl PartialOrd for CueCodecState
impl PartialOrd for CueCodecState
impl Copy for CueCodecState
impl Eq for CueCodecState
impl StructuralPartialEq for CueCodecState