pub struct CueDuration(pub u64);Expand description
The duration of the block, expressed in Segment Ticks, which are based on TimestampScale; see (#timestamp-ticks).
If missing, the track’s DefaultDuration does not apply and no duration information is available in terms of the cues.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueDuration
impl Clone for CueDuration
Sourcefn clone(&self) -> CueDuration
fn clone(&self) -> CueDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueDuration
impl Debug for CueDuration
Sourceimpl Default for CueDuration
impl Default for CueDuration
Sourceimpl Deref for CueDuration
impl Deref for CueDuration
Sourceimpl Element for CueDuration
impl Element for CueDuration
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CueDuration
impl Hash for CueDuration
Sourceimpl Ord for CueDuration
impl Ord for CueDuration
Sourcefn cmp(&self, other: &CueDuration) -> Ordering
fn cmp(&self, other: &CueDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueDuration
impl PartialEq for CueDuration
Sourceimpl PartialOrd for CueDuration
impl PartialOrd for CueDuration
impl Copy for CueDuration
impl Eq for CueDuration
impl StructuralPartialEq for CueDuration