pub struct CueRefCluster(pub u64);Expand description
The Segment Position of the Cluster containing the referenced Block.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueRefCluster
impl Clone for CueRefCluster
Sourcefn clone(&self) -> CueRefCluster
fn clone(&self) -> CueRefCluster
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueRefCluster
impl Debug for CueRefCluster
Sourceimpl Default for CueRefCluster
impl Default for CueRefCluster
Sourceimpl Deref for CueRefCluster
impl Deref for CueRefCluster
Sourceimpl Element for CueRefCluster
impl Element for CueRefCluster
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CueRefCluster
impl Hash for CueRefCluster
Sourceimpl Ord for CueRefCluster
impl Ord for CueRefCluster
Sourcefn cmp(&self, other: &CueRefCluster) -> Ordering
fn cmp(&self, other: &CueRefCluster) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueRefCluster
impl PartialEq for CueRefCluster
Sourceimpl PartialOrd for CueRefCluster
impl PartialOrd for CueRefCluster
impl Copy for CueRefCluster
impl Eq for CueRefCluster
impl StructuralPartialEq for CueRefCluster