pub struct CueRefNumber(pub u64);Expand description
Number of the referenced Block of Track X in the specified Cluster.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueRefNumber
impl Clone for CueRefNumber
Sourcefn clone(&self) -> CueRefNumber
fn clone(&self) -> CueRefNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueRefNumber
impl Debug for CueRefNumber
Sourceimpl Default for CueRefNumber
impl Default for CueRefNumber
Sourceimpl Deref for CueRefNumber
impl Deref for CueRefNumber
Sourceimpl Element for CueRefNumber
impl Element for CueRefNumber
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for CueRefNumber
impl Hash for CueRefNumber
Sourceimpl Ord for CueRefNumber
impl Ord for CueRefNumber
Sourcefn cmp(&self, other: &CueRefNumber) -> Ordering
fn cmp(&self, other: &CueRefNumber) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueRefNumber
impl PartialEq for CueRefNumber
Sourceimpl PartialOrd for CueRefNumber
impl PartialOrd for CueRefNumber
impl Copy for CueRefNumber
impl Eq for CueRefNumber
impl StructuralPartialEq for CueRefNumber