pub struct CueRefTime(pub u64);Expand description
Timestamp of the referenced Block, expressed in Segment Ticks which is based on TimestampScale; see (#timestamp-ticks).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for CueRefTime
impl Clone for CueRefTime
Sourcefn clone(&self) -> CueRefTime
fn clone(&self) -> CueRefTime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CueRefTime
impl Debug for CueRefTime
Sourceimpl Default for CueRefTime
impl Default for CueRefTime
Sourceimpl Deref for CueRefTime
impl Deref for CueRefTime
Sourceimpl Element for CueRefTime
impl Element for CueRefTime
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for CueRefTime
impl Hash for CueRefTime
Sourceimpl Ord for CueRefTime
impl Ord for CueRefTime
Sourcefn cmp(&self, other: &CueRefTime) -> Ordering
fn cmp(&self, other: &CueRefTime) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CueRefTime
impl PartialEq for CueRefTime
Sourceimpl PartialOrd for CueRefTime
impl PartialOrd for CueRefTime
impl Copy for CueRefTime
impl Eq for CueRefTime
impl StructuralPartialEq for CueRefTime