CueTrackPositions

Struct CueTrackPositions 

pub struct CueTrackPositions {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub cue_track: CueTrack,
    pub cue_cluster_position: CueClusterPosition,
    pub cue_relative_position: Option<CueRelativePosition>,
    pub cue_duration: Option<CueDuration>,
    pub cue_block_number: Option<CueBlockNumber>,
    pub cue_codec_state: CueCodecState,
    pub cue_reference: Vec<CueReference>,
}
Contain positions for different tracks corresponding to the timestamp.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

cue_track: CueTrack

The track for which a position is given.

cue_cluster_position: CueClusterPosition

The Segment Position (segment-position) of the Cluster containing the associated Block.

cue_relative_position: Option<CueRelativePosition>

The relative position inside the Cluster of the referenced SimpleBlock or BlockGroup with 0 being the first possible position for an Element inside that Cluster.

cue_duration: Option<CueDuration>

The duration of the block, expressed in Segment Ticks which is based on TimestampScale; see timestamp-ticks. If missing, the track’s DefaultDuration does not apply and no duration information is available in terms of the cues.

cue_block_number: Option<CueBlockNumber>

Number of the Block in the specified Cluster.

cue_codec_state: CueCodecState

The Segment Position (segment-position) of the Codec State corresponding to this Cue Element. 0 means that the data is taken from the initial Track Entry.

cue_reference: Vec<CueReference>

The Clusters containing the referenced Blocks.