pub struct Cues {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub cue_point: Vec<CuePoint>,
}Expand description
A Top-Level Element to speed seeking access. All entries are local to the Segment. This Element SHOULD be set when the Segment is not transmitted as a live stream (see #livestreaming).
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
cue_point: Vec<CuePoint>Contains all information relative to a seek point in the Segment.