pub struct DateUtc(pub i64);Expand description
The date and time that the Segment was created by the muxing application or library.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Element for DateUtc
impl Element for DateUtc
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for DateUtc
impl Ord for DateUtc
Sourceimpl PartialOrd for DateUtc
impl PartialOrd for DateUtc
impl Eq for DateUtc
impl StructuralPartialEq for DateUtc