pub struct DefaultDecodedFieldDuration(pub u64);Expand description
The period between two successive fields at the output of the decoding process, expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks). See (#defaultdecodedfieldduration) for more information.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DefaultDecodedFieldDuration
impl Clone for DefaultDecodedFieldDuration
Sourcefn clone(&self) -> DefaultDecodedFieldDuration
fn clone(&self) -> DefaultDecodedFieldDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultDecodedFieldDuration
impl Debug for DefaultDecodedFieldDuration
Sourceimpl Deref for DefaultDecodedFieldDuration
impl Deref for DefaultDecodedFieldDuration
Sourceimpl Element for DefaultDecodedFieldDuration
impl Element for DefaultDecodedFieldDuration
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for DefaultDecodedFieldDuration
impl Hash for DefaultDecodedFieldDuration
Sourceimpl Ord for DefaultDecodedFieldDuration
impl Ord for DefaultDecodedFieldDuration
Sourcefn cmp(&self, other: &DefaultDecodedFieldDuration) -> Ordering
fn cmp(&self, other: &DefaultDecodedFieldDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DefaultDecodedFieldDuration
impl PartialOrd for DefaultDecodedFieldDuration
impl Copy for DefaultDecodedFieldDuration
impl Eq for DefaultDecodedFieldDuration
impl StructuralPartialEq for DefaultDecodedFieldDuration