pub struct DefaultDuration(pub u64);Expand description
Number of nanoseconds per frame, expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks) (“frame” in the Matroska sense – one element put into a (Simple)Block).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DefaultDuration
impl Clone for DefaultDuration
Sourcefn clone(&self) -> DefaultDuration
fn clone(&self) -> DefaultDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultDuration
impl Debug for DefaultDuration
Sourceimpl Default for DefaultDuration
impl Default for DefaultDuration
Sourceimpl Deref for DefaultDuration
impl Deref for DefaultDuration
Sourceimpl Element for DefaultDuration
impl Element for DefaultDuration
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for DefaultDuration
impl Hash for DefaultDuration
Sourceimpl Ord for DefaultDuration
impl Ord for DefaultDuration
Sourcefn cmp(&self, other: &DefaultDuration) -> Ordering
fn cmp(&self, other: &DefaultDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DefaultDuration
impl PartialEq for DefaultDuration
Sourceimpl PartialOrd for DefaultDuration
impl PartialOrd for DefaultDuration
impl Copy for DefaultDuration
impl Eq for DefaultDuration
impl StructuralPartialEq for DefaultDuration