pub struct DisplayHeight(pub u64);Expand description
Height of the video frames to display. Applies to the video frame after cropping (PixelCrop* Elements).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DisplayHeight
impl Clone for DisplayHeight
Sourcefn clone(&self) -> DisplayHeight
fn clone(&self) -> DisplayHeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisplayHeight
impl Debug for DisplayHeight
Sourceimpl Default for DisplayHeight
impl Default for DisplayHeight
Sourceimpl Deref for DisplayHeight
impl Deref for DisplayHeight
Sourceimpl Element for DisplayHeight
impl Element for DisplayHeight
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for DisplayHeight
impl Hash for DisplayHeight
Sourceimpl Ord for DisplayHeight
impl Ord for DisplayHeight
Sourcefn cmp(&self, other: &DisplayHeight) -> Ordering
fn cmp(&self, other: &DisplayHeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DisplayHeight
impl PartialEq for DisplayHeight
Sourceimpl PartialOrd for DisplayHeight
impl PartialOrd for DisplayHeight
impl Copy for DisplayHeight
impl Eq for DisplayHeight
impl StructuralPartialEq for DisplayHeight