pub struct DisplayWidth(pub u64);Expand description
Width of the video frames to display. Applies to the video frame after cropping (PixelCrop* Elements).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DisplayWidth
impl Clone for DisplayWidth
Sourcefn clone(&self) -> DisplayWidth
fn clone(&self) -> DisplayWidth
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisplayWidth
impl Debug for DisplayWidth
Sourceimpl Default for DisplayWidth
impl Default for DisplayWidth
Sourceimpl Deref for DisplayWidth
impl Deref for DisplayWidth
Sourceimpl Element for DisplayWidth
impl Element for DisplayWidth
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for DisplayWidth
impl Hash for DisplayWidth
Sourceimpl Ord for DisplayWidth
impl Ord for DisplayWidth
Sourcefn cmp(&self, other: &DisplayWidth) -> Ordering
fn cmp(&self, other: &DisplayWidth) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DisplayWidth
impl PartialEq for DisplayWidth
Sourceimpl PartialOrd for DisplayWidth
impl PartialOrd for DisplayWidth
impl Copy for DisplayWidth
impl Eq for DisplayWidth
impl StructuralPartialEq for DisplayWidth