pub struct DocTypeVersion(pub u64);Expand description
DocTypeVersion element, indicates the version of the document type.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for DocTypeVersion
impl Clone for DocTypeVersion
Sourcefn clone(&self) -> DocTypeVersion
fn clone(&self) -> DocTypeVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocTypeVersion
impl Debug for DocTypeVersion
Sourceimpl Default for DocTypeVersion
impl Default for DocTypeVersion
Sourceimpl Deref for DocTypeVersion
impl Deref for DocTypeVersion
Sourceimpl Element for DocTypeVersion
impl Element for DocTypeVersion
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for DocTypeVersion
impl Hash for DocTypeVersion
Sourceimpl Ord for DocTypeVersion
impl Ord for DocTypeVersion
Sourcefn cmp(&self, other: &DocTypeVersion) -> Ordering
fn cmp(&self, other: &DocTypeVersion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DocTypeVersion
impl PartialEq for DocTypeVersion
Sourceimpl PartialOrd for DocTypeVersion
impl PartialOrd for DocTypeVersion
impl Copy for DocTypeVersion
impl Eq for DocTypeVersion
impl StructuralPartialEq for DocTypeVersion