Ebml

Struct Ebml 

pub struct Ebml {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub ebml_version: Option<EbmlVersion>,
    pub ebml_read_version: Option<EbmlReadVersion>,
    pub ebml_max_id_length: EbmlMaxIdLength,
    pub ebml_max_size_length: EbmlMaxSizeLength,
    pub doc_type: Option<DocType>,
    pub doc_type_version: Option<DocTypeVersion>,
    pub doc_type_read_version: Option<DocTypeReadVersion>,
}
EBML element, the first top-level element in a Matroska file.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

ebml_version: Option<EbmlVersion>

EBMLVersion element, indicates the version of EBML used.

ebml_read_version: Option<EbmlReadVersion>

EBMLReadVersion element, indicates the minimum version of EBML required to read the file.

ebml_max_id_length: EbmlMaxIdLength

EBMLMaxIDLength element, indicates the maximum length of an EBML ID in bytes.

ebml_max_size_length: EbmlMaxSizeLength

EBMLMaxSizeLength element, indicates the maximum length of an EBML size in bytes.

doc_type: Option<DocType>

DocType element, indicates the type of document. For Matroska files, this is usually “matroska” or “webm”.

doc_type_version: Option<DocTypeVersion>

DocTypeVersion element, indicates the version of the document type.

doc_type_read_version: Option<DocTypeReadVersion>

DocTypeReadVersion element, indicates the minimum version of the document type required to read the file.