pub struct EbmlMaxIdLength(pub u64);Expand description
EBMLMaxIDLength in ebml
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EbmlMaxIdLength
impl Clone for EbmlMaxIdLength
Sourcefn clone(&self) -> EbmlMaxIdLength
fn clone(&self) -> EbmlMaxIdLength
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EbmlMaxIdLength
impl Debug for EbmlMaxIdLength
Sourceimpl Default for EbmlMaxIdLength
impl Default for EbmlMaxIdLength
Sourceimpl Deref for EbmlMaxIdLength
impl Deref for EbmlMaxIdLength
Sourceimpl Element for EbmlMaxIdLength
impl Element for EbmlMaxIdLength
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for EbmlMaxIdLength
impl Hash for EbmlMaxIdLength
Sourceimpl Ord for EbmlMaxIdLength
impl Ord for EbmlMaxIdLength
Sourcefn cmp(&self, other: &EbmlMaxIdLength) -> Ordering
fn cmp(&self, other: &EbmlMaxIdLength) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EbmlMaxIdLength
impl PartialEq for EbmlMaxIdLength
Sourceimpl PartialOrd for EbmlMaxIdLength
impl PartialOrd for EbmlMaxIdLength
impl Copy for EbmlMaxIdLength
impl Eq for EbmlMaxIdLength
impl StructuralPartialEq for EbmlMaxIdLength