pub struct EbmlMaxSizeLength(pub u64);Expand description
EBMLMaxSizeLength in ebml
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EbmlMaxSizeLength
impl Clone for EbmlMaxSizeLength
Sourcefn clone(&self) -> EbmlMaxSizeLength
fn clone(&self) -> EbmlMaxSizeLength
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EbmlMaxSizeLength
impl Debug for EbmlMaxSizeLength
Sourceimpl Default for EbmlMaxSizeLength
impl Default for EbmlMaxSizeLength
Sourceimpl Deref for EbmlMaxSizeLength
impl Deref for EbmlMaxSizeLength
Sourceimpl Element for EbmlMaxSizeLength
impl Element for EbmlMaxSizeLength
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for EbmlMaxSizeLength
impl Hash for EbmlMaxSizeLength
Sourceimpl Ord for EbmlMaxSizeLength
impl Ord for EbmlMaxSizeLength
Sourcefn cmp(&self, other: &EbmlMaxSizeLength) -> Ordering
fn cmp(&self, other: &EbmlMaxSizeLength) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EbmlMaxSizeLength
impl PartialEq for EbmlMaxSizeLength
Sourceimpl PartialOrd for EbmlMaxSizeLength
impl PartialOrd for EbmlMaxSizeLength
impl Copy for EbmlMaxSizeLength
impl Eq for EbmlMaxSizeLength
impl StructuralPartialEq for EbmlMaxSizeLength