pub struct EbmlReadVersion(pub u64);Expand description
EBMLReadVersion element, indicates the read version of EBML used.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EbmlReadVersion
impl Clone for EbmlReadVersion
Sourcefn clone(&self) -> EbmlReadVersion
fn clone(&self) -> EbmlReadVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EbmlReadVersion
impl Debug for EbmlReadVersion
Sourceimpl Default for EbmlReadVersion
impl Default for EbmlReadVersion
Sourceimpl Deref for EbmlReadVersion
impl Deref for EbmlReadVersion
Sourceimpl Element for EbmlReadVersion
impl Element for EbmlReadVersion
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for EbmlReadVersion
impl Hash for EbmlReadVersion
Sourceimpl Ord for EbmlReadVersion
impl Ord for EbmlReadVersion
Sourcefn cmp(&self, other: &EbmlReadVersion) -> Ordering
fn cmp(&self, other: &EbmlReadVersion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EbmlReadVersion
impl PartialEq for EbmlReadVersion
Sourceimpl PartialOrd for EbmlReadVersion
impl PartialOrd for EbmlReadVersion
impl Copy for EbmlReadVersion
impl Eq for EbmlReadVersion
impl StructuralPartialEq for EbmlReadVersion