pub struct EbmlVersion(pub u64);Expand description
EBMLVersion element, indicates the version of EBML used.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EbmlVersion
impl Clone for EbmlVersion
Sourcefn clone(&self) -> EbmlVersion
fn clone(&self) -> EbmlVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EbmlVersion
impl Debug for EbmlVersion
Sourceimpl Default for EbmlVersion
impl Default for EbmlVersion
Sourceimpl Deref for EbmlVersion
impl Deref for EbmlVersion
Sourceimpl Element for EbmlVersion
impl Element for EbmlVersion
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for EbmlVersion
impl Hash for EbmlVersion
Sourceimpl Ord for EbmlVersion
impl Ord for EbmlVersion
Sourcefn cmp(&self, other: &EbmlVersion) -> Ordering
fn cmp(&self, other: &EbmlVersion) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EbmlVersion
impl PartialEq for EbmlVersion
Sourceimpl PartialOrd for EbmlVersion
impl PartialOrd for EbmlVersion
impl Copy for EbmlVersion
impl Eq for EbmlVersion
impl StructuralPartialEq for EbmlVersion