pub struct EditionDisplay {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub edition_string: EditionString,
pub edition_language_ietf: Vec<EditionLanguageIetf>,
}Expand description
Contains a possible string to use for the edition display for the given languages.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
edition_string: EditionStringContains the string to use as the edition name.
edition_language_ietf: Vec<EditionLanguageIetf>One language corresponding to the EditionString, in the [@!BCP47] form; see basics on language codes.