EditionEntry

Struct EditionEntry 

pub struct EditionEntry {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub edition_uid: Option<EditionUid>,
    pub edition_flag_hidden: EditionFlagHidden,
    pub edition_flag_default: EditionFlagDefault,
    pub edition_flag_ordered: EditionFlagOrdered,
    pub edition_display: Vec<EditionDisplay>,
    pub chapter_atom: Vec<ChapterAtom>,
}
Contains all information about a Segment edition.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

edition_uid: Option<EditionUid>

A unique ID to identify the edition. It’s useful for tagging an edition.

edition_flag_hidden: EditionFlagHidden

Set to 1 if an edition is hidden. Hidden editions SHOULD NOT be available to the user interface (but still to Control Tracks; see notes on Chapter flags).

edition_flag_default: EditionFlagDefault

Set to 1 if the edition SHOULD be used as the default one.

edition_flag_ordered: EditionFlagOrdered

Set to 1 if the chapters can be defined multiple times and the order to play them is enforced; see editionflagordered.

edition_display: Vec<EditionDisplay>

Contains a possible string to use for the edition display for the given languages.

chapter_atom: Vec<ChapterAtom>

Contains the atom information to use as the chapter atom (apply to all tracks).