pub struct EditionFlagHidden(pub u64);Expand description
Set to 1 if an edition is hidden. Hidden editions SHOULD NOT be available to the user interface
(but still be available to Control Tracks; see (#chapter-flags) on Chapter flags).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EditionFlagHidden
impl Clone for EditionFlagHidden
Sourcefn clone(&self) -> EditionFlagHidden
fn clone(&self) -> EditionFlagHidden
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EditionFlagHidden
impl Debug for EditionFlagHidden
Sourceimpl Default for EditionFlagHidden
impl Default for EditionFlagHidden
Sourceimpl Deref for EditionFlagHidden
impl Deref for EditionFlagHidden
Sourceimpl Element for EditionFlagHidden
impl Element for EditionFlagHidden
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for EditionFlagHidden
impl Hash for EditionFlagHidden
Sourceimpl Ord for EditionFlagHidden
impl Ord for EditionFlagHidden
Sourcefn cmp(&self, other: &EditionFlagHidden) -> Ordering
fn cmp(&self, other: &EditionFlagHidden) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EditionFlagHidden
impl PartialEq for EditionFlagHidden
Sourceimpl PartialOrd for EditionFlagHidden
impl PartialOrd for EditionFlagHidden
impl Copy for EditionFlagHidden
impl Eq for EditionFlagHidden
impl StructuralPartialEq for EditionFlagHidden