pub struct EditionFlagOrdered(pub u64);Expand description
Set to 1 if the chapters can be defined multiple times and the order to play them is enforced; see (#editionflagordered).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for EditionFlagOrdered
impl Clone for EditionFlagOrdered
Sourcefn clone(&self) -> EditionFlagOrdered
fn clone(&self) -> EditionFlagOrdered
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EditionFlagOrdered
impl Debug for EditionFlagOrdered
Sourceimpl Default for EditionFlagOrdered
impl Default for EditionFlagOrdered
Sourceimpl Deref for EditionFlagOrdered
impl Deref for EditionFlagOrdered
Sourceimpl Element for EditionFlagOrdered
impl Element for EditionFlagOrdered
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for EditionFlagOrdered
impl Hash for EditionFlagOrdered
Sourceimpl Ord for EditionFlagOrdered
impl Ord for EditionFlagOrdered
Sourcefn cmp(&self, other: &EditionFlagOrdered) -> Ordering
fn cmp(&self, other: &EditionFlagOrdered) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EditionFlagOrdered
impl PartialEq for EditionFlagOrdered
Sourceimpl PartialOrd for EditionFlagOrdered
impl PartialOrd for EditionFlagOrdered
impl Copy for EditionFlagOrdered
impl Eq for EditionFlagOrdered
impl StructuralPartialEq for EditionFlagOrdered