pub struct Emphasis(pub u64);Expand description
Audio emphasis applied on audio samples. The player MUST apply the inverse emphasis to get the proper audio samples.
Tuple Fields
0: u64Trait Implementations
impl Copy for Emphasis
Sourceimpl Element for Emphasis
impl Element for Emphasis
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
impl Eq for Emphasis
Sourceimpl Ord for Emphasis
impl Ord for Emphasis
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Emphasis
impl PartialOrd for Emphasis
impl StructuralPartialEq for Emphasis