pub struct FieldOrder(pub u64);Expand description
Specifies the field ordering of video frames in this track.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FieldOrder
impl Clone for FieldOrder
Sourcefn clone(&self) -> FieldOrder
fn clone(&self) -> FieldOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FieldOrder
impl Debug for FieldOrder
Sourceimpl Default for FieldOrder
impl Default for FieldOrder
Sourceimpl Deref for FieldOrder
impl Deref for FieldOrder
Sourceimpl Element for FieldOrder
impl Element for FieldOrder
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FieldOrder
impl Hash for FieldOrder
Sourceimpl Ord for FieldOrder
impl Ord for FieldOrder
Sourcefn cmp(&self, other: &FieldOrder) -> Ordering
fn cmp(&self, other: &FieldOrder) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FieldOrder
impl PartialEq for FieldOrder
Sourceimpl PartialOrd for FieldOrder
impl PartialOrd for FieldOrder
impl Copy for FieldOrder
impl Eq for FieldOrder
impl StructuralPartialEq for FieldOrder