pub struct FileUsedEndTime(pub u64);Expand description
The timestamp at which this optimized font attachment goes out of context, expressed in Segment Ticks, which are based on
TimestampScale. See [@?DivXWorldFonts].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FileUsedEndTime
impl Clone for FileUsedEndTime
Sourcefn clone(&self) -> FileUsedEndTime
fn clone(&self) -> FileUsedEndTime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileUsedEndTime
impl Debug for FileUsedEndTime
Sourceimpl Default for FileUsedEndTime
impl Default for FileUsedEndTime
Sourceimpl Deref for FileUsedEndTime
impl Deref for FileUsedEndTime
Sourceimpl Element for FileUsedEndTime
impl Element for FileUsedEndTime
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FileUsedEndTime
impl Hash for FileUsedEndTime
Sourceimpl Ord for FileUsedEndTime
impl Ord for FileUsedEndTime
Sourcefn cmp(&self, other: &FileUsedEndTime) -> Ordering
fn cmp(&self, other: &FileUsedEndTime) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FileUsedEndTime
impl PartialEq for FileUsedEndTime
Sourceimpl PartialOrd for FileUsedEndTime
impl PartialOrd for FileUsedEndTime
impl Copy for FileUsedEndTime
impl Eq for FileUsedEndTime
impl StructuralPartialEq for FileUsedEndTime