pub struct FileUsedStartTime(pub u64);Expand description
The timestamp at which this optimized font attachment comes into context, expressed in Segment Ticks, which are based on
TimestampScale. See [@?DivXWorldFonts].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FileUsedStartTime
impl Clone for FileUsedStartTime
Sourcefn clone(&self) -> FileUsedStartTime
fn clone(&self) -> FileUsedStartTime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileUsedStartTime
impl Debug for FileUsedStartTime
Sourceimpl Default for FileUsedStartTime
impl Default for FileUsedStartTime
Sourceimpl Deref for FileUsedStartTime
impl Deref for FileUsedStartTime
Sourceimpl Element for FileUsedStartTime
impl Element for FileUsedStartTime
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FileUsedStartTime
impl Hash for FileUsedStartTime
Sourceimpl Ord for FileUsedStartTime
impl Ord for FileUsedStartTime
Sourcefn cmp(&self, other: &FileUsedStartTime) -> Ordering
fn cmp(&self, other: &FileUsedStartTime) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FileUsedStartTime
impl PartialEq for FileUsedStartTime
Sourceimpl PartialOrd for FileUsedStartTime
impl PartialOrd for FileUsedStartTime
impl Copy for FileUsedStartTime
impl Eq for FileUsedStartTime
impl StructuralPartialEq for FileUsedStartTime