pub struct FlagCommentary(pub u64);Expand description
Set to 1 if and only if the track contains commentary.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagCommentary
impl Clone for FlagCommentary
Sourcefn clone(&self) -> FlagCommentary
fn clone(&self) -> FlagCommentary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagCommentary
impl Debug for FlagCommentary
Sourceimpl Default for FlagCommentary
impl Default for FlagCommentary
Sourceimpl Deref for FlagCommentary
impl Deref for FlagCommentary
Sourceimpl Element for FlagCommentary
impl Element for FlagCommentary
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagCommentary
impl Hash for FlagCommentary
Sourceimpl Ord for FlagCommentary
impl Ord for FlagCommentary
Sourcefn cmp(&self, other: &FlagCommentary) -> Ordering
fn cmp(&self, other: &FlagCommentary) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagCommentary
impl PartialEq for FlagCommentary
Sourceimpl PartialOrd for FlagCommentary
impl PartialOrd for FlagCommentary
impl Copy for FlagCommentary
impl Eq for FlagCommentary
impl StructuralPartialEq for FlagCommentary