pub struct FlagDefault(pub u64);Expand description
Set to 1 if the track (audio, video, or subtitles) is eligible for automatic selection by the player; see (#default-track-selection) for more details.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagDefault
impl Clone for FlagDefault
Sourcefn clone(&self) -> FlagDefault
fn clone(&self) -> FlagDefault
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagDefault
impl Debug for FlagDefault
Sourceimpl Default for FlagDefault
impl Default for FlagDefault
Sourceimpl Deref for FlagDefault
impl Deref for FlagDefault
Sourceimpl Element for FlagDefault
impl Element for FlagDefault
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagDefault
impl Hash for FlagDefault
Sourceimpl Ord for FlagDefault
impl Ord for FlagDefault
Sourcefn cmp(&self, other: &FlagDefault) -> Ordering
fn cmp(&self, other: &FlagDefault) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagDefault
impl PartialEq for FlagDefault
Sourceimpl PartialOrd for FlagDefault
impl PartialOrd for FlagDefault
impl Copy for FlagDefault
impl Eq for FlagDefault
impl StructuralPartialEq for FlagDefault