pub struct FlagEnabled(pub u64);Expand description
Set to 1 if the track is usable. It is possible to turn a track that is not usable into a usable track using chapter codecs or control tracks.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagEnabled
impl Clone for FlagEnabled
Sourcefn clone(&self) -> FlagEnabled
fn clone(&self) -> FlagEnabled
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagEnabled
impl Debug for FlagEnabled
Sourceimpl Default for FlagEnabled
impl Default for FlagEnabled
Sourceimpl Deref for FlagEnabled
impl Deref for FlagEnabled
Sourceimpl Element for FlagEnabled
impl Element for FlagEnabled
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagEnabled
impl Hash for FlagEnabled
Sourceimpl Ord for FlagEnabled
impl Ord for FlagEnabled
Sourcefn cmp(&self, other: &FlagEnabled) -> Ordering
fn cmp(&self, other: &FlagEnabled) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagEnabled
impl PartialEq for FlagEnabled
Sourceimpl PartialOrd for FlagEnabled
impl PartialOrd for FlagEnabled
impl Copy for FlagEnabled
impl Eq for FlagEnabled
impl StructuralPartialEq for FlagEnabled