pub struct FlagForced(pub u64);Expand description
Applies only to subtitles. Set to 1 if the track is eligible for automatic selection by the player if it matches the user’s language preference, even if the user’s preferences would not normally enable subtitles with the selected audio track; this can be used for tracks containing only translations of audio in foreign languages or on-screen text. See (#default-track-selection) for more details.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagForced
impl Clone for FlagForced
Sourcefn clone(&self) -> FlagForced
fn clone(&self) -> FlagForced
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagForced
impl Debug for FlagForced
Sourceimpl Default for FlagForced
impl Default for FlagForced
Sourceimpl Deref for FlagForced
impl Deref for FlagForced
Sourceimpl Element for FlagForced
impl Element for FlagForced
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagForced
impl Hash for FlagForced
Sourceimpl Ord for FlagForced
impl Ord for FlagForced
Sourcefn cmp(&self, other: &FlagForced) -> Ordering
fn cmp(&self, other: &FlagForced) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagForced
impl PartialEq for FlagForced
Sourceimpl PartialOrd for FlagForced
impl PartialOrd for FlagForced
impl Copy for FlagForced
impl Eq for FlagForced
impl StructuralPartialEq for FlagForced