pub struct FlagInterlaced(pub u64);Expand description
Specifies whether the video frames in this track are interlaced.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagInterlaced
impl Clone for FlagInterlaced
Sourcefn clone(&self) -> FlagInterlaced
fn clone(&self) -> FlagInterlaced
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagInterlaced
impl Debug for FlagInterlaced
Sourceimpl Default for FlagInterlaced
impl Default for FlagInterlaced
Sourceimpl Deref for FlagInterlaced
impl Deref for FlagInterlaced
Sourceimpl Element for FlagInterlaced
impl Element for FlagInterlaced
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for FlagInterlaced
impl Hash for FlagInterlaced
Sourceimpl Ord for FlagInterlaced
impl Ord for FlagInterlaced
Sourcefn cmp(&self, other: &FlagInterlaced) -> Ordering
fn cmp(&self, other: &FlagInterlaced) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagInterlaced
impl PartialEq for FlagInterlaced
Sourceimpl PartialOrd for FlagInterlaced
impl PartialOrd for FlagInterlaced
impl Copy for FlagInterlaced
impl Eq for FlagInterlaced
impl StructuralPartialEq for FlagInterlaced