pub struct FlagLacing(pub u64);Expand description
Set to 1 if the track MAY contain blocks that use lacing. When set to 0, all blocks MUST have their lacing flags set to “no lacing”; see (#block-lacing) on ‘Block’ Lacing.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagLacing
impl Clone for FlagLacing
Sourcefn clone(&self) -> FlagLacing
fn clone(&self) -> FlagLacing
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagLacing
impl Debug for FlagLacing
Sourceimpl Default for FlagLacing
impl Default for FlagLacing
Sourceimpl Deref for FlagLacing
impl Deref for FlagLacing
Sourceimpl Element for FlagLacing
impl Element for FlagLacing
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for FlagLacing
impl Hash for FlagLacing
Sourceimpl Ord for FlagLacing
impl Ord for FlagLacing
Sourcefn cmp(&self, other: &FlagLacing) -> Ordering
fn cmp(&self, other: &FlagLacing) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagLacing
impl PartialEq for FlagLacing
Sourceimpl PartialOrd for FlagLacing
impl PartialOrd for FlagLacing
impl Copy for FlagLacing
impl Eq for FlagLacing
impl StructuralPartialEq for FlagLacing