pub struct FlagTextDescriptions(pub u64);Expand description
Set to 1 if and only if the track contains textual descriptions of video content.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagTextDescriptions
impl Clone for FlagTextDescriptions
Sourcefn clone(&self) -> FlagTextDescriptions
fn clone(&self) -> FlagTextDescriptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagTextDescriptions
impl Debug for FlagTextDescriptions
Sourceimpl Default for FlagTextDescriptions
impl Default for FlagTextDescriptions
Sourceimpl Deref for FlagTextDescriptions
impl Deref for FlagTextDescriptions
Sourceimpl Element for FlagTextDescriptions
impl Element for FlagTextDescriptions
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagTextDescriptions
impl Hash for FlagTextDescriptions
Sourceimpl Ord for FlagTextDescriptions
impl Ord for FlagTextDescriptions
Sourcefn cmp(&self, other: &FlagTextDescriptions) -> Ordering
fn cmp(&self, other: &FlagTextDescriptions) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagTextDescriptions
impl PartialEq for FlagTextDescriptions
Sourceimpl PartialOrd for FlagTextDescriptions
impl PartialOrd for FlagTextDescriptions
impl Copy for FlagTextDescriptions
impl Eq for FlagTextDescriptions
impl StructuralPartialEq for FlagTextDescriptions