pub struct FlagVisualImpaired(pub u64);Expand description
Set to 1 if and only if the track is suitable for users with visual impairments.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FlagVisualImpaired
impl Clone for FlagVisualImpaired
Sourcefn clone(&self) -> FlagVisualImpaired
fn clone(&self) -> FlagVisualImpaired
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlagVisualImpaired
impl Debug for FlagVisualImpaired
Sourceimpl Default for FlagVisualImpaired
impl Default for FlagVisualImpaired
Sourceimpl Deref for FlagVisualImpaired
impl Deref for FlagVisualImpaired
Sourceimpl Element for FlagVisualImpaired
impl Element for FlagVisualImpaired
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for FlagVisualImpaired
impl Hash for FlagVisualImpaired
Sourceimpl Ord for FlagVisualImpaired
impl Ord for FlagVisualImpaired
Sourcefn cmp(&self, other: &FlagVisualImpaired) -> Ordering
fn cmp(&self, other: &FlagVisualImpaired) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FlagVisualImpaired
impl PartialEq for FlagVisualImpaired
Sourceimpl PartialOrd for FlagVisualImpaired
impl PartialOrd for FlagVisualImpaired
impl Copy for FlagVisualImpaired
impl Eq for FlagVisualImpaired
impl StructuralPartialEq for FlagVisualImpaired