Info

Struct Info 

pub struct Info {
Show 16 fields pub crc32: Option<Crc32>, pub void: Option<Void>, pub segment_uuid: Option<SegmentUuid>, pub segment_filename: Option<SegmentFilename>, pub prev_uuid: Option<PrevUuid>, pub prev_filename: Option<PrevFilename>, pub next_uuid: Option<NextUuid>, pub next_filename: Option<NextFilename>, pub segment_family: Vec<SegmentFamily>, pub chapter_translate: Vec<ChapterTranslate>, pub timestamp_scale: TimestampScale, pub duration: Option<Duration>, pub date_utc: Option<DateUtc>, pub title: Option<Title>, pub muxing_app: MuxingApp, pub writing_app: WritingApp,
}
Contains general information about the Segment.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

segment_uuid: Option<SegmentUuid>

A randomly generated unique ID to identify the Segment amongst many others (128 bits). It is equivalent to a UUID v4 [@!RFC4122] with all bits randomly (or pseudo-randomly) chosen. An actual UUID v4 value, where some bits are not random, MAY also be used. If the Segment is a part of a Linked Segment, then this Element is REQUIRED. The value of the unique ID MUST contain at least one bit set to 1.

segment_filename: Option<SegmentFilename>

A filename corresponding to this Segment.

prev_uuid: Option<PrevUuid>

An ID to identify the previous Segment of a Linked Segment. If the Segment is a part of a Linked Segment that uses Hard Linking (hard-linking), then either the PrevUUID or the NextUUID Element is REQUIRED. If a Segment contains a PrevUUID but not a NextUUID, then it MAY be considered as the last Segment of the Linked Segment. The PrevUUID MUST NOT be equal to the SegmentUUID.

prev_filename: Option<PrevFilename>

A filename corresponding to the file of the previous Linked Segment. Provision of the previous filename is for display convenience, but PrevUUID SHOULD be considered authoritative for identifying the previous Segment in a Linked Segment.

next_uuid: Option<NextUuid>

An ID to identify the next Segment of a Linked Segment. If the Segment is a part of a Linked Segment that uses Hard Linking (hard-linking), then either the PrevUUID or the NextUUID Element is REQUIRED. If a Segment contains a NextUUID but not a PrevUUID, then it MAY be considered as the first Segment of the Linked Segment. The NextUUID MUST NOT be equal to the SegmentUUID.

next_filename: Option<NextFilename>

A filename corresponding to the file of the next Linked Segment. Provision of the next filename is for display convenience, but NextUUID SHOULD be considered authoritative for identifying the Next Segment.

segment_family: Vec<SegmentFamily>

A unique ID that all Segments of a Linked Segment MUST share (128 bits). It is equivalent to a UUID v4 [@!RFC4122] with all bits randomly (or pseudo-randomly) chosen. An actual UUID v4 value, where some bits are not random, MAY also be used. If the Segment Info contains a ChapterTranslate element, this Element is REQUIRED.

chapter_translate: Vec<ChapterTranslate>

The mapping between this Segment and a segment value in the given Chapter Codec. Chapter Codec may need to address different segments, but they may not know of the way to identify such segment when stored in Matroska. This element and its child elements add a way to map the internal segments known to the Chapter Codec to the Segment IDs in Matroska. This allows remuxing a file with Chapter Codec without changing the content of the codec data, just the Segment mapping.

timestamp_scale: TimestampScale

Base unit for Segment Ticks and Track Ticks, in nanoseconds. A TimestampScale value of 1000000 means scaled timestamps in the Segment are expressed in milliseconds; see timestamps on how to interpret timestamps.

duration: Option<Duration>

Duration of the Segment, expressed in Segment Ticks which is based on TimestampScale; see timestamp-ticks.

date_utc: Option<DateUtc>

The date and time that the Segment was created by the muxing application or library.

title: Option<Title>

General name of the Segment

muxing_app: MuxingApp

Muxing application or library (example: “libmatroska-0.4.3”). Include the full name of the application or library followed by the version number.

writing_app: WritingApp

Writing application (example: “mkvmerge-0.3.3”). Include the full name of the application followed by the version number.