pub struct LaceNumber(pub u64);Expand description
The reverse number of the frame in the lace (0 is the last frame, 1 is the next to last, etc.). Being able to interpret this element is not required for playback.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for LaceNumber
impl Clone for LaceNumber
Sourcefn clone(&self) -> LaceNumber
fn clone(&self) -> LaceNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LaceNumber
impl Debug for LaceNumber
Sourceimpl Default for LaceNumber
impl Default for LaceNumber
Sourceimpl Deref for LaceNumber
impl Deref for LaceNumber
Sourceimpl Element for LaceNumber
impl Element for LaceNumber
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for LaceNumber
impl Hash for LaceNumber
Sourceimpl Ord for LaceNumber
impl Ord for LaceNumber
Sourcefn cmp(&self, other: &LaceNumber) -> Ordering
fn cmp(&self, other: &LaceNumber) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LaceNumber
impl PartialEq for LaceNumber
Sourceimpl PartialOrd for LaceNumber
impl PartialOrd for LaceNumber
impl Copy for LaceNumber
impl Eq for LaceNumber
impl StructuralPartialEq for LaceNumber