pub struct MasteringMetadata {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub primary_r_chromaticity_x: Option<PrimaryRChromaticityX>,
pub primary_r_chromaticity_y: Option<PrimaryRChromaticityY>,
pub primary_g_chromaticity_x: Option<PrimaryGChromaticityX>,
pub primary_g_chromaticity_y: Option<PrimaryGChromaticityY>,
pub primary_b_chromaticity_x: Option<PrimaryBChromaticityX>,
pub primary_b_chromaticity_y: Option<PrimaryBChromaticityY>,
pub white_point_chromaticity_x: Option<WhitePointChromaticityX>,
pub white_point_chromaticity_y: Option<WhitePointChromaticityY>,
pub luminance_max: Option<LuminanceMax>,
pub luminance_min: Option<LuminanceMin>,
}Expand description
SMPTE 2086 mastering data.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
primary_r_chromaticity_x: Option<PrimaryRChromaticityX>Red X chromaticity coordinate, as defined by [@!CIE-1931].
primary_r_chromaticity_y: Option<PrimaryRChromaticityY>Red Y chromaticity coordinate, as defined by [@!CIE-1931].
primary_g_chromaticity_x: Option<PrimaryGChromaticityX>Green X chromaticity coordinate, as defined by [@!CIE-1931].
primary_g_chromaticity_y: Option<PrimaryGChromaticityY>Green Y chromaticity coordinate, as defined by [@!CIE-1931].
primary_b_chromaticity_x: Option<PrimaryBChromaticityX>Blue X chromaticity coordinate, as defined by [@!CIE-1931].
primary_b_chromaticity_y: Option<PrimaryBChromaticityY>Blue Y chromaticity coordinate, as defined by [@!CIE-1931].
white_point_chromaticity_x: Option<WhitePointChromaticityX>White point X chromaticity coordinate, as defined by [@!CIE-1931].
white_point_chromaticity_y: Option<WhitePointChromaticityY>White point Y chromaticity coordinate, as defined by [@!CIE-1931].
luminance_max: Option<LuminanceMax>Maximum luminance. Represented in candelas per square meter (cd/m^2^).
luminance_min: Option<LuminanceMin>Minimum luminance. Represented in candelas per square meter (cd/m^2^).