pub struct MaxCache(pub u64);Expand description
The maximum cache size necessary to store referenced frames in and the current frame. 0 means no cache is needed.
Tuple Fields
0: u64Trait Implementations
impl Copy for MaxCache
Sourceimpl Element for MaxCache
impl Element for MaxCache
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
impl Eq for MaxCache
Sourceimpl Ord for MaxCache
impl Ord for MaxCache
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for MaxCache
impl PartialOrd for MaxCache
impl StructuralPartialEq for MaxCache