pub struct MaxFall(pub u64);Expand description
Maximum brightness of a single full frame (Maximum Frame-Average Light Level) in candelas per square meter (cd/m^2^).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for MaxFall
impl Element for MaxFall
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for MaxFall
impl Ord for MaxFall
Sourceimpl PartialOrd for MaxFall
impl PartialOrd for MaxFall
impl Copy for MaxFall
impl Eq for MaxFall
impl StructuralPartialEq for MaxFall