pub struct MinCache(pub u64);Expand description
The minimum number of frames a player should be able to cache during playback. If set to 0, the reference pseudo-cache system is not used.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for MinCache
impl Element for MinCache
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Ord for MinCache
impl Ord for MinCache
Sourceimpl PartialOrd for MinCache
impl PartialOrd for MinCache
impl Copy for MinCache
impl Eq for MinCache
impl StructuralPartialEq for MinCache