pub struct PixelCropBottom(pub u64);Expand description
The number of video pixels to remove at the bottom of the image.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelCropBottom
impl Clone for PixelCropBottom
Sourcefn clone(&self) -> PixelCropBottom
fn clone(&self) -> PixelCropBottom
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelCropBottom
impl Debug for PixelCropBottom
Sourceimpl Default for PixelCropBottom
impl Default for PixelCropBottom
Sourceimpl Deref for PixelCropBottom
impl Deref for PixelCropBottom
Sourceimpl Element for PixelCropBottom
impl Element for PixelCropBottom
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelCropBottom
impl Hash for PixelCropBottom
Sourceimpl Ord for PixelCropBottom
impl Ord for PixelCropBottom
Sourcefn cmp(&self, other: &PixelCropBottom) -> Ordering
fn cmp(&self, other: &PixelCropBottom) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelCropBottom
impl PartialEq for PixelCropBottom
Sourceimpl PartialOrd for PixelCropBottom
impl PartialOrd for PixelCropBottom
impl Copy for PixelCropBottom
impl Eq for PixelCropBottom
impl StructuralPartialEq for PixelCropBottom