pub struct PixelCropLeft(pub u64);Expand description
The number of video pixels to remove on the left of the image.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelCropLeft
impl Clone for PixelCropLeft
Sourcefn clone(&self) -> PixelCropLeft
fn clone(&self) -> PixelCropLeft
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelCropLeft
impl Debug for PixelCropLeft
Sourceimpl Default for PixelCropLeft
impl Default for PixelCropLeft
Sourceimpl Deref for PixelCropLeft
impl Deref for PixelCropLeft
Sourceimpl Element for PixelCropLeft
impl Element for PixelCropLeft
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelCropLeft
impl Hash for PixelCropLeft
Sourceimpl Ord for PixelCropLeft
impl Ord for PixelCropLeft
Sourcefn cmp(&self, other: &PixelCropLeft) -> Ordering
fn cmp(&self, other: &PixelCropLeft) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelCropLeft
impl PartialEq for PixelCropLeft
Sourceimpl PartialOrd for PixelCropLeft
impl PartialOrd for PixelCropLeft
impl Copy for PixelCropLeft
impl Eq for PixelCropLeft
impl StructuralPartialEq for PixelCropLeft