pub struct PixelCropRight(pub u64);Expand description
The number of video pixels to remove on the right of the image.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelCropRight
impl Clone for PixelCropRight
Sourcefn clone(&self) -> PixelCropRight
fn clone(&self) -> PixelCropRight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelCropRight
impl Debug for PixelCropRight
Sourceimpl Default for PixelCropRight
impl Default for PixelCropRight
Sourceimpl Deref for PixelCropRight
impl Deref for PixelCropRight
Sourceimpl Element for PixelCropRight
impl Element for PixelCropRight
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelCropRight
impl Hash for PixelCropRight
Sourceimpl Ord for PixelCropRight
impl Ord for PixelCropRight
Sourcefn cmp(&self, other: &PixelCropRight) -> Ordering
fn cmp(&self, other: &PixelCropRight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelCropRight
impl PartialEq for PixelCropRight
Sourceimpl PartialOrd for PixelCropRight
impl PartialOrd for PixelCropRight
impl Copy for PixelCropRight
impl Eq for PixelCropRight
impl StructuralPartialEq for PixelCropRight