pub struct PixelCropTop(pub u64);Expand description
The number of video pixels to remove at the top of the image.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelCropTop
impl Clone for PixelCropTop
Sourcefn clone(&self) -> PixelCropTop
fn clone(&self) -> PixelCropTop
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelCropTop
impl Debug for PixelCropTop
Sourceimpl Default for PixelCropTop
impl Default for PixelCropTop
Sourceimpl Deref for PixelCropTop
impl Deref for PixelCropTop
Sourceimpl Element for PixelCropTop
impl Element for PixelCropTop
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelCropTop
impl Hash for PixelCropTop
Sourceimpl Ord for PixelCropTop
impl Ord for PixelCropTop
Sourcefn cmp(&self, other: &PixelCropTop) -> Ordering
fn cmp(&self, other: &PixelCropTop) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelCropTop
impl PartialEq for PixelCropTop
Sourceimpl PartialOrd for PixelCropTop
impl PartialOrd for PixelCropTop
impl Copy for PixelCropTop
impl Eq for PixelCropTop
impl StructuralPartialEq for PixelCropTop