pub struct PixelHeight(pub u64);Expand description
Height of the encoded video frames in pixels.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelHeight
impl Clone for PixelHeight
Sourcefn clone(&self) -> PixelHeight
fn clone(&self) -> PixelHeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelHeight
impl Debug for PixelHeight
Sourceimpl Default for PixelHeight
impl Default for PixelHeight
Sourceimpl Deref for PixelHeight
impl Deref for PixelHeight
Sourceimpl Element for PixelHeight
impl Element for PixelHeight
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelHeight
impl Hash for PixelHeight
Sourceimpl Ord for PixelHeight
impl Ord for PixelHeight
Sourcefn cmp(&self, other: &PixelHeight) -> Ordering
fn cmp(&self, other: &PixelHeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelHeight
impl PartialEq for PixelHeight
Sourceimpl PartialOrd for PixelHeight
impl PartialOrd for PixelHeight
impl Copy for PixelHeight
impl Eq for PixelHeight
impl StructuralPartialEq for PixelHeight