pub struct PixelWidth(pub u64);Expand description
Width of the encoded video frames in pixels.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PixelWidth
impl Clone for PixelWidth
Sourcefn clone(&self) -> PixelWidth
fn clone(&self) -> PixelWidth
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PixelWidth
impl Debug for PixelWidth
Sourceimpl Default for PixelWidth
impl Default for PixelWidth
Sourceimpl Deref for PixelWidth
impl Deref for PixelWidth
Sourceimpl Element for PixelWidth
impl Element for PixelWidth
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for PixelWidth
impl Hash for PixelWidth
Sourceimpl Ord for PixelWidth
impl Ord for PixelWidth
Sourcefn cmp(&self, other: &PixelWidth) -> Ordering
fn cmp(&self, other: &PixelWidth) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PixelWidth
impl PartialEq for PixelWidth
Sourceimpl PartialOrd for PixelWidth
impl PartialOrd for PixelWidth
impl Copy for PixelWidth
impl Eq for PixelWidth
impl StructuralPartialEq for PixelWidth