pub struct Primaries(pub u64);Expand description
The color primaries of the video. For clarity,
the value and meanings for Primaries are adopted from Table 2 of [@!ITU-H.273].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for Primaries
impl Element for Primaries
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Ord for Primaries
impl Ord for Primaries
Sourceimpl PartialOrd for Primaries
impl PartialOrd for Primaries
impl Copy for Primaries
impl Eq for Primaries
impl StructuralPartialEq for Primaries