pub struct ProjectionPoseRoll(pub f64);Expand description
Specifies a roll rotation to the projection. Value represents a
counter-clockwise rotation, in degrees, around the forward vector. This
rotation must be applied after the ProjectionPoseYaw and
ProjectionPosePitch rotations. The value of this element
MUST be in the -180 to 180 degree range, both inclusive. Setting ProjectionPoseRoll to 180 or -180 degrees and
ProjectionPoseYaw to 180 or -180 degrees with
ProjectionPosePitch set to 0 degrees flips the image vertically.
Setting ProjectionPoseRoll to 180 or -180 degrees with
ProjectionPoseYaw and ProjectionPosePitch set to 0 degrees
flips the image horizontally and vertically.
Tuple Fields
0: f64Methods from Deref<Target = f64>
pub const RADIX: u32 = 2u32
pub const MANTISSA_DIGITS: u32 = 53u32
pub const DIGITS: u32 = 15u32
pub const EPSILON: f64 = 2.2204460492503131E-16f64
pub const MIN: f64 = -1.7976931348623157E+308f64
pub const MIN_POSITIVE: f64 = 2.2250738585072014E-308f64
pub const MAX: f64 = 1.7976931348623157E+308f64
pub const MIN_EXP: i32 = -1_021i32
pub const MAX_EXP: i32 = 1_024i32
pub const MIN_10_EXP: i32 = -307i32
pub const MAX_10_EXP: i32 = 308i32
pub const NAN: f64 = NaN_f64
pub const INFINITY: f64 = +Inf_f64
pub const NEG_INFINITY: f64 = -Inf_f64
1.62.0 · Sourcepub fn total_cmp(&self, other: &f64) -> Ordering
pub fn total_cmp(&self, other: &f64) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f64. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f64,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f64::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f64::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f64::NAN` could be positive or negative, which will affect the sort order.
if f64::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f64::NAN, -5.0, 0.1, 10.0, 99.0, f64::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f64::INFINITY, f64::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Clone for ProjectionPoseRoll
impl Clone for ProjectionPoseRoll
Sourcefn clone(&self) -> ProjectionPoseRoll
fn clone(&self) -> ProjectionPoseRoll
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ProjectionPoseRoll
impl Debug for ProjectionPoseRoll
Sourceimpl Default for ProjectionPoseRoll
impl Default for ProjectionPoseRoll
Sourceimpl Deref for ProjectionPoseRoll
impl Deref for ProjectionPoseRoll
Sourceimpl Element for ProjectionPoseRoll
impl Element for ProjectionPoseRoll
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Sourceimpl PartialEq for ProjectionPoseRoll
impl PartialEq for ProjectionPoseRoll
Sourceimpl PartialOrd for ProjectionPoseRoll
impl PartialOrd for ProjectionPoseRoll
impl Copy for ProjectionPoseRoll
impl StructuralPartialEq for ProjectionPoseRoll