pub struct ProjectionType(pub u64);Expand description
Describes the projection used for this video track.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ProjectionType
impl Clone for ProjectionType
Sourcefn clone(&self) -> ProjectionType
fn clone(&self) -> ProjectionType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectionType
impl Debug for ProjectionType
Sourceimpl Default for ProjectionType
impl Default for ProjectionType
Sourceimpl Deref for ProjectionType
impl Deref for ProjectionType
Sourceimpl Element for ProjectionType
impl Element for ProjectionType
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for ProjectionType
impl Hash for ProjectionType
Sourceimpl Ord for ProjectionType
impl Ord for ProjectionType
Sourcefn cmp(&self, other: &ProjectionType) -> Ordering
fn cmp(&self, other: &ProjectionType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProjectionType
impl PartialEq for ProjectionType
Sourceimpl PartialOrd for ProjectionType
impl PartialOrd for ProjectionType
impl Copy for ProjectionType
impl Eq for ProjectionType
impl StructuralPartialEq for ProjectionType