pub struct Range(pub u64);Expand description
Clipping of the color ranges.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for Range
impl Element for Range
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for Range
impl Ord for Range
Sourceimpl PartialOrd for Range
impl PartialOrd for Range
impl Copy for Range
impl Eq for Range
impl StructuralPartialEq for Range