pub struct ReferenceBlock(pub i64);Expand description
A timestamp value, relative to the timestamp of the Block in this BlockGroup, expressed in Track Ticks; see (#timestamp-ticks).
This is used to reference other frames necessary to decode this frame.
The relative value SHOULD correspond to a valid Block that this Block depends on.
Historically, Matroska Writers didn’t write the actual Block(s) that this Block depends on, but they did write some Block(s) in the past.
The value “0” MAY also be used to signify that this Block cannot be decoded on its own, but the necessary reference Block(s) is unknown. In this case, other ReferenceBlock elements MUST NOT be found in the same BlockGroup. If the BlockGroup doesn’t have a ReferenceBlock element, then the Block it contains can be decoded without using any other Block data.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for ReferenceBlock
impl Clone for ReferenceBlock
Sourcefn clone(&self) -> ReferenceBlock
fn clone(&self) -> ReferenceBlock
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Copy for ReferenceBlock
Sourceimpl Debug for ReferenceBlock
impl Debug for ReferenceBlock
Sourceimpl Default for ReferenceBlock
impl Default for ReferenceBlock
Sourceimpl Deref for ReferenceBlock
impl Deref for ReferenceBlock
Sourceimpl Element for ReferenceBlock
impl Element for ReferenceBlock
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
impl Eq for ReferenceBlock
Sourceimpl Hash for ReferenceBlock
impl Hash for ReferenceBlock
Sourceimpl Ord for ReferenceBlock
impl Ord for ReferenceBlock
Sourcefn cmp(&self, other: &ReferenceBlock) -> Ordering
fn cmp(&self, other: &ReferenceBlock) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for ReferenceBlock
impl PartialEq for ReferenceBlock
Sourcefn eq(&self, other: &ReferenceBlock) -> bool
fn eq(&self, other: &ReferenceBlock) -> bool
self and other values to be equal, and is used by ==.