pub struct SeekPosition(pub u64);Expand description
The Segment Position ((#segment-position)) of a Top-Level Element.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for SeekPosition
impl Clone for SeekPosition
Sourcefn clone(&self) -> SeekPosition
fn clone(&self) -> SeekPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SeekPosition
impl Debug for SeekPosition
Sourceimpl Default for SeekPosition
impl Default for SeekPosition
Sourceimpl Deref for SeekPosition
impl Deref for SeekPosition
Sourceimpl Element for SeekPosition
impl Element for SeekPosition
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for SeekPosition
impl Hash for SeekPosition
Sourceimpl Ord for SeekPosition
impl Ord for SeekPosition
Sourcefn cmp(&self, other: &SeekPosition) -> Ordering
fn cmp(&self, other: &SeekPosition) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SeekPosition
impl PartialEq for SeekPosition
Sourceimpl PartialOrd for SeekPosition
impl PartialOrd for SeekPosition
impl Copy for SeekPosition
impl Eq for SeekPosition
impl StructuralPartialEq for SeekPosition