Struct Segment Copy item path Source pub struct Segment {
pub crc32: Option <Crc32 >,
pub void: Option <Void >,
pub seek_head: Vec <SeekHead >,
pub info: Info ,
pub cluster: Vec <Cluster >,
pub tracks: Option <Tracks >,
pub cues: Option <Cues >,
pub attachments: Option <Attachments >,
pub chapters: Option <Chapters >,
pub tags: Vec <Tags >,
}Expand description The Root Element that contains all other Top-Level Elements; see data-layout.
Optional CRC-32 element for integrity checking.
void element, useful for reserving space during writing.
Contains seeking information of Top-Level Elements; see data-layout.
Contains general information about the Segment.
The Top-Level Element containing the (monolithic) Block structure.
A Top-Level Element of information with many tracks described.
A Top-Level Element to speed seeking access. All entries are local to the Segment. This Element SHOULD be set when the Segment is not transmitted as a live stream (see #livestreaming).
A system to define basic menus and partition data. For more detailed information, look at the Chapters explanation in chapters.
Element containing metadata describing Tracks, Editions, Chapters, Attachments, or the Segment as a whole. A list of valid tags can be found in Matroska tagging RFC .
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more EBML ID of the element.
Decode the body of the element from a buffer.
Encode the body of the element to a buffer.
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Available on crate feature tokio only.
Read an element from a reader provided the header.
Available on crate feature tokio only.
Read Self from a reader.
Available on crate feature tokio only.
Write an element to a writer asynchronously.
Available on crate feature tokio only.
Write to a writer asynchronously.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
Read an element from a reader provided the header.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Write an element to a writer.