Struct SimpleTag Copy item path Source pub struct SimpleTag {
pub crc32: Option <Crc32 >,
pub void: Option <Void >,
pub tag_name: TagName ,
pub tag_language: TagLanguage ,
pub tag_language_bcp47: Option <TagLanguageBcp47 >,
pub tag_default: TagDefault ,
pub tag_string: Option <TagString >,
pub tag_binary: Option <TagBinary >,
pub simple_tag: Vec <SimpleTag >,
}Expand description Contains general information about the target.
Optional CRC-32 element for integrity checking.
void element, useful for reserving space during writing.
The name of the Tag that is going to be stored.
Specifies the language of the tag specified, in the Matroska languages form; see basics on language codes. This Element MUST be ignored if the TagLanguageBCP47 Element is used within the same SimpleTag Element.
The language used in the TagString, in the [@!BCP47] form; see basics on language codes. If this Element is used, then any TagLanguage Elements used in the same SimpleTag MUST be ignored.
A boolean value to indicate if this is the default/original language to use for the given tag.
The values of the Tag, if it is binary. Note that this cannot be used in the same SimpleTag as TagString.
Nested simple tags, if any.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more EBML ID of the element.
Decode the body of the element from a buffer.
Encode the body of the element to a buffer.
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Available on crate feature tokio only.
Read an element from a reader provided the header.
Available on crate feature tokio only.
Read Self from a reader.
Available on crate feature tokio only.
Write an element to a writer asynchronously.
Available on crate feature tokio only.
Write to a writer asynchronously.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
Read an element from a reader provided the header.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Write an element to a writer.