pub struct SliceDuration(pub u64);Expand description
The duration to apply to the element, expressed in Track Ticks; see (#timestamp-ticks).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for SliceDuration
impl Clone for SliceDuration
Sourcefn clone(&self) -> SliceDuration
fn clone(&self) -> SliceDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SliceDuration
impl Debug for SliceDuration
Sourceimpl Default for SliceDuration
impl Default for SliceDuration
Sourceimpl Deref for SliceDuration
impl Deref for SliceDuration
Sourceimpl Element for SliceDuration
impl Element for SliceDuration
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for SliceDuration
impl Hash for SliceDuration
Sourceimpl Ord for SliceDuration
impl Ord for SliceDuration
Sourcefn cmp(&self, other: &SliceDuration) -> Ordering
fn cmp(&self, other: &SliceDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SliceDuration
impl PartialEq for SliceDuration
Sourceimpl PartialOrd for SliceDuration
impl PartialOrd for SliceDuration
impl Copy for SliceDuration
impl Eq for SliceDuration
impl StructuralPartialEq for SliceDuration