pub struct StereoMode(pub u64);Expand description
Stereo-3D video mode. See (#multi-planar-and-3d-videos) for more details.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for StereoMode
impl Clone for StereoMode
Sourcefn clone(&self) -> StereoMode
fn clone(&self) -> StereoMode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StereoMode
impl Debug for StereoMode
Sourceimpl Default for StereoMode
impl Default for StereoMode
Sourceimpl Deref for StereoMode
impl Deref for StereoMode
Sourceimpl Element for StereoMode
impl Element for StereoMode
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for StereoMode
impl Hash for StereoMode
Sourceimpl Ord for StereoMode
impl Ord for StereoMode
Sourcefn cmp(&self, other: &StereoMode) -> Ordering
fn cmp(&self, other: &StereoMode) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StereoMode
impl PartialEq for StereoMode
Sourceimpl PartialOrd for StereoMode
impl PartialOrd for StereoMode
impl Copy for StereoMode
impl Eq for StereoMode
impl StructuralPartialEq for StereoMode