pub struct Tag {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub targets: Targets,
pub simple_tag: Vec<SimpleTag>,
}Expand description
A single metadata descriptor.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
targets: TargetsSpecifies which other elements the metadata represented by the Tag applies to. If empty or omitted, then the Tag describes everything in the Segment.
simple_tag: Vec<SimpleTag>Contains general information about the target.