pub struct TagBlockAddIDValue(pub u64);Expand description
A BlockAddIDValuethat identifies the Block Addition Mapping that the tags belong to.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TagBlockAddIDValue
impl Clone for TagBlockAddIDValue
Sourcefn clone(&self) -> TagBlockAddIDValue
fn clone(&self) -> TagBlockAddIDValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TagBlockAddIDValue
impl Debug for TagBlockAddIDValue
Sourceimpl Default for TagBlockAddIDValue
impl Default for TagBlockAddIDValue
Sourceimpl Deref for TagBlockAddIDValue
impl Deref for TagBlockAddIDValue
Sourceimpl Element for TagBlockAddIDValue
impl Element for TagBlockAddIDValue
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TagBlockAddIDValue
impl Hash for TagBlockAddIDValue
Sourceimpl Ord for TagBlockAddIDValue
impl Ord for TagBlockAddIDValue
Sourcefn cmp(&self, other: &TagBlockAddIDValue) -> Ordering
fn cmp(&self, other: &TagBlockAddIDValue) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TagBlockAddIDValue
impl PartialEq for TagBlockAddIDValue
Sourceimpl PartialOrd for TagBlockAddIDValue
impl PartialOrd for TagBlockAddIDValue
impl Copy for TagBlockAddIDValue
impl Eq for TagBlockAddIDValue
impl StructuralPartialEq for TagBlockAddIDValue