pub struct TagChapterUid(pub u64);Expand description
A UID that identifies the Chapter(s) that the tags belong to.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TagChapterUid
impl Clone for TagChapterUid
Sourcefn clone(&self) -> TagChapterUid
fn clone(&self) -> TagChapterUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TagChapterUid
impl Debug for TagChapterUid
Sourceimpl Default for TagChapterUid
impl Default for TagChapterUid
Sourceimpl Deref for TagChapterUid
impl Deref for TagChapterUid
Sourceimpl Element for TagChapterUid
impl Element for TagChapterUid
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for TagChapterUid
impl Hash for TagChapterUid
Sourceimpl Ord for TagChapterUid
impl Ord for TagChapterUid
Sourcefn cmp(&self, other: &TagChapterUid) -> Ordering
fn cmp(&self, other: &TagChapterUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TagChapterUid
impl PartialEq for TagChapterUid
Sourceimpl PartialOrd for TagChapterUid
impl PartialOrd for TagChapterUid
impl Copy for TagChapterUid
impl Eq for TagChapterUid
impl StructuralPartialEq for TagChapterUid