pub struct TagDefaultBogus(pub u64);Expand description
A variant of the TagDefault element with a bogus element ID; see (#tagdefault-element).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TagDefaultBogus
impl Clone for TagDefaultBogus
Sourcefn clone(&self) -> TagDefaultBogus
fn clone(&self) -> TagDefaultBogus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TagDefaultBogus
impl Debug for TagDefaultBogus
Sourceimpl Default for TagDefaultBogus
impl Default for TagDefaultBogus
Sourceimpl Deref for TagDefaultBogus
impl Deref for TagDefaultBogus
Sourceimpl Element for TagDefaultBogus
impl Element for TagDefaultBogus
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TagDefaultBogus
impl Hash for TagDefaultBogus
Sourceimpl Ord for TagDefaultBogus
impl Ord for TagDefaultBogus
Sourcefn cmp(&self, other: &TagDefaultBogus) -> Ordering
fn cmp(&self, other: &TagDefaultBogus) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TagDefaultBogus
impl PartialEq for TagDefaultBogus
Sourceimpl PartialOrd for TagDefaultBogus
impl PartialOrd for TagDefaultBogus
impl Copy for TagDefaultBogus
impl Eq for TagDefaultBogus
impl StructuralPartialEq for TagDefaultBogus