pub struct TagEditionUid(pub u64);Expand description
A UID that identifies the EditionEntry(s) that the tags belong to.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TagEditionUid
impl Clone for TagEditionUid
Sourcefn clone(&self) -> TagEditionUid
fn clone(&self) -> TagEditionUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TagEditionUid
impl Debug for TagEditionUid
Sourceimpl Default for TagEditionUid
impl Default for TagEditionUid
Sourceimpl Deref for TagEditionUid
impl Deref for TagEditionUid
Sourceimpl Element for TagEditionUid
impl Element for TagEditionUid
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for TagEditionUid
impl Hash for TagEditionUid
Sourceimpl Ord for TagEditionUid
impl Ord for TagEditionUid
Sourcefn cmp(&self, other: &TagEditionUid) -> Ordering
fn cmp(&self, other: &TagEditionUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TagEditionUid
impl PartialEq for TagEditionUid
Sourceimpl PartialOrd for TagEditionUid
impl PartialOrd for TagEditionUid
impl Copy for TagEditionUid
impl Eq for TagEditionUid
impl StructuralPartialEq for TagEditionUid