pub struct TagTrackUid(pub u64);Expand description
A UID that identifies the Track(s) that the tags belong to.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TagTrackUid
impl Clone for TagTrackUid
Sourcefn clone(&self) -> TagTrackUid
fn clone(&self) -> TagTrackUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TagTrackUid
impl Debug for TagTrackUid
Sourceimpl Default for TagTrackUid
impl Default for TagTrackUid
Sourceimpl Deref for TagTrackUid
impl Deref for TagTrackUid
Sourceimpl Element for TagTrackUid
impl Element for TagTrackUid
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TagTrackUid
impl Hash for TagTrackUid
Sourceimpl Ord for TagTrackUid
impl Ord for TagTrackUid
Sourcefn cmp(&self, other: &TagTrackUid) -> Ordering
fn cmp(&self, other: &TagTrackUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TagTrackUid
impl PartialEq for TagTrackUid
Sourceimpl PartialOrd for TagTrackUid
impl PartialOrd for TagTrackUid
impl Copy for TagTrackUid
impl Eq for TagTrackUid
impl StructuralPartialEq for TagTrackUid