pub struct Tags {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub tag: Vec<Tag>,
}Expand description
Element containing metadata describing Tracks, Editions, Chapters, Attachments, or the Segment as a whole. A list of valid tags can be found in Matroska tagging RFC.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
tag: Vec<Tag>A single metadata descriptor.