pub struct TargetTypeValue(pub u64);Expand description
A number to indicate the logical level of the target.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TargetTypeValue
impl Clone for TargetTypeValue
Sourcefn clone(&self) -> TargetTypeValue
fn clone(&self) -> TargetTypeValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetTypeValue
impl Debug for TargetTypeValue
Sourceimpl Default for TargetTypeValue
impl Default for TargetTypeValue
Sourceimpl Deref for TargetTypeValue
impl Deref for TargetTypeValue
Sourceimpl Element for TargetTypeValue
impl Element for TargetTypeValue
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TargetTypeValue
impl Hash for TargetTypeValue
Sourceimpl Ord for TargetTypeValue
impl Ord for TargetTypeValue
Sourcefn cmp(&self, other: &TargetTypeValue) -> Ordering
fn cmp(&self, other: &TargetTypeValue) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TargetTypeValue
impl PartialEq for TargetTypeValue
Sourceimpl PartialOrd for TargetTypeValue
impl PartialOrd for TargetTypeValue
impl Copy for TargetTypeValue
impl Eq for TargetTypeValue
impl StructuralPartialEq for TargetTypeValue