pub struct TimestampScale(pub u64);Expand description
Base unit for Segment Ticks and Track Ticks, in nanoseconds. A TimestampScale value of 1000000 means scaled timestamps in the Segment are expressed in milliseconds; see (#timestamps) on how to interpret timestamps.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TimestampScale
impl Clone for TimestampScale
Sourcefn clone(&self) -> TimestampScale
fn clone(&self) -> TimestampScale
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimestampScale
impl Debug for TimestampScale
Sourceimpl Default for TimestampScale
impl Default for TimestampScale
Sourceimpl Deref for TimestampScale
impl Deref for TimestampScale
Sourceimpl Element for TimestampScale
impl Element for TimestampScale
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for TimestampScale
impl Hash for TimestampScale
Sourceimpl Ord for TimestampScale
impl Ord for TimestampScale
Sourcefn cmp(&self, other: &TimestampScale) -> Ordering
fn cmp(&self, other: &TimestampScale) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TimestampScale
impl PartialEq for TimestampScale
Sourceimpl PartialOrd for TimestampScale
impl PartialOrd for TimestampScale
impl Copy for TimestampScale
impl Eq for TimestampScale
impl StructuralPartialEq for TimestampScale