pub struct TrackCombinePlanes {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub track_plane: Vec<TrackPlane>,
}Expand description
Contains the list of all video plane tracks that need to be combined to create this 3D track
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
track_plane: Vec<TrackPlane>Contains a video plane track that need to be combined to create this 3D track