pub struct TrackJoinBlocks {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub track_join_uid: Vec<TrackJoinUid>,
}Expand description
Contains the list of all tracks whose Blocks need to be combined to create this virtual track
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
track_join_uid: Vec<TrackJoinUid>The trackUID number of a track whose blocks are used to create this virtual track.