pub struct TrackJoinUid(pub u64);Expand description
The TrackUID number of a track whose blocks are used to create this virtual track.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackJoinUid
impl Clone for TrackJoinUid
Sourcefn clone(&self) -> TrackJoinUid
fn clone(&self) -> TrackJoinUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackJoinUid
impl Debug for TrackJoinUid
Sourceimpl Default for TrackJoinUid
impl Default for TrackJoinUid
Sourceimpl Deref for TrackJoinUid
impl Deref for TrackJoinUid
Sourceimpl Element for TrackJoinUid
impl Element for TrackJoinUid
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackJoinUid
impl Hash for TrackJoinUid
Sourceimpl Ord for TrackJoinUid
impl Ord for TrackJoinUid
Sourcefn cmp(&self, other: &TrackJoinUid) -> Ordering
fn cmp(&self, other: &TrackJoinUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackJoinUid
impl PartialEq for TrackJoinUid
Sourceimpl PartialOrd for TrackJoinUid
impl PartialOrd for TrackJoinUid
impl Copy for TrackJoinUid
impl Eq for TrackJoinUid
impl StructuralPartialEq for TrackJoinUid