pub struct TrackNumber(pub u64);Expand description
The track number as used in the Block Header.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackNumber
impl Clone for TrackNumber
Sourcefn clone(&self) -> TrackNumber
fn clone(&self) -> TrackNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackNumber
impl Debug for TrackNumber
Sourceimpl Default for TrackNumber
impl Default for TrackNumber
Sourceimpl Deref for TrackNumber
impl Deref for TrackNumber
Sourceimpl Element for TrackNumber
impl Element for TrackNumber
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackNumber
impl Hash for TrackNumber
Sourceimpl Ord for TrackNumber
impl Ord for TrackNumber
Sourcefn cmp(&self, other: &TrackNumber) -> Ordering
fn cmp(&self, other: &TrackNumber) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackNumber
impl PartialEq for TrackNumber
Sourceimpl PartialOrd for TrackNumber
impl PartialOrd for TrackNumber
impl Copy for TrackNumber
impl Eq for TrackNumber
impl StructuralPartialEq for TrackNumber