pub struct TrackOffset(pub i64);Expand description
A value to add to the Block’s Timestamp, expressed in Matroska Ticks – i.e., in nanoseconds; see (#timestamp-ticks).
This can be used to adjust the playback offset of a track.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for TrackOffset
impl Clone for TrackOffset
Sourcefn clone(&self) -> TrackOffset
fn clone(&self) -> TrackOffset
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackOffset
impl Debug for TrackOffset
Sourceimpl Default for TrackOffset
impl Default for TrackOffset
Sourceimpl Deref for TrackOffset
impl Deref for TrackOffset
Sourceimpl Element for TrackOffset
impl Element for TrackOffset
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourceimpl Hash for TrackOffset
impl Hash for TrackOffset
Sourceimpl Ord for TrackOffset
impl Ord for TrackOffset
Sourcefn cmp(&self, other: &TrackOffset) -> Ordering
fn cmp(&self, other: &TrackOffset) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackOffset
impl PartialEq for TrackOffset
Sourceimpl PartialOrd for TrackOffset
impl PartialOrd for TrackOffset
impl Copy for TrackOffset
impl Eq for TrackOffset
impl StructuralPartialEq for TrackOffset