pub struct TrackOperation {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub track_combine_planes: Option<TrackCombinePlanes>,
pub track_join_blocks: Option<TrackJoinBlocks>,
}Expand description
Operation that needs to be applied on tracks to create this virtual track. For more details look at notes.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
track_combine_planes: Option<TrackCombinePlanes>Contains the list of all video plane tracks that need to be combined to create this 3D track
track_join_blocks: Option<TrackJoinBlocks>Contains the list of all tracks whose Blocks need to be combined to create this virtual track