pub struct TrackOverlay(pub u64);Expand description
Specify that this track is an overlay track for the Track specified (in the u-integer).
This means that when this track has a gap on SilentTracks, the overlay track should be used instead. The order of multiple TrackOverlay matters; the first one is the one that should be used.
If the first one is not found, it should be the second, etc.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackOverlay
impl Clone for TrackOverlay
Sourcefn clone(&self) -> TrackOverlay
fn clone(&self) -> TrackOverlay
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackOverlay
impl Debug for TrackOverlay
Sourceimpl Default for TrackOverlay
impl Default for TrackOverlay
Sourceimpl Deref for TrackOverlay
impl Deref for TrackOverlay
Sourceimpl Element for TrackOverlay
impl Element for TrackOverlay
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackOverlay
impl Hash for TrackOverlay
Sourceimpl Ord for TrackOverlay
impl Ord for TrackOverlay
Sourcefn cmp(&self, other: &TrackOverlay) -> Ordering
fn cmp(&self, other: &TrackOverlay) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackOverlay
impl PartialEq for TrackOverlay
Sourceimpl PartialOrd for TrackOverlay
impl PartialOrd for TrackOverlay
impl Copy for TrackOverlay
impl Eq for TrackOverlay
impl StructuralPartialEq for TrackOverlay