pub struct TrackPlaneType(pub u64);Expand description
The kind of plane this track corresponds to.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackPlaneType
impl Clone for TrackPlaneType
Sourcefn clone(&self) -> TrackPlaneType
fn clone(&self) -> TrackPlaneType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackPlaneType
impl Debug for TrackPlaneType
Sourceimpl Default for TrackPlaneType
impl Default for TrackPlaneType
Sourceimpl Deref for TrackPlaneType
impl Deref for TrackPlaneType
Sourceimpl Element for TrackPlaneType
impl Element for TrackPlaneType
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackPlaneType
impl Hash for TrackPlaneType
Sourceimpl Ord for TrackPlaneType
impl Ord for TrackPlaneType
Sourcefn cmp(&self, other: &TrackPlaneType) -> Ordering
fn cmp(&self, other: &TrackPlaneType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackPlaneType
impl PartialEq for TrackPlaneType
Sourceimpl PartialOrd for TrackPlaneType
impl PartialOrd for TrackPlaneType
impl Copy for TrackPlaneType
impl Eq for TrackPlaneType
impl StructuralPartialEq for TrackPlaneType