pub struct TrackPlaneUid(pub u64);Expand description
The TrackUID number of the track representing the plane.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackPlaneUid
impl Clone for TrackPlaneUid
Sourcefn clone(&self) -> TrackPlaneUid
fn clone(&self) -> TrackPlaneUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackPlaneUid
impl Debug for TrackPlaneUid
Sourceimpl Default for TrackPlaneUid
impl Default for TrackPlaneUid
Sourceimpl Deref for TrackPlaneUid
impl Deref for TrackPlaneUid
Sourceimpl Element for TrackPlaneUid
impl Element for TrackPlaneUid
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackPlaneUid
impl Hash for TrackPlaneUid
Sourceimpl Ord for TrackPlaneUid
impl Ord for TrackPlaneUid
Sourcefn cmp(&self, other: &TrackPlaneUid) -> Ordering
fn cmp(&self, other: &TrackPlaneUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackPlaneUid
impl PartialEq for TrackPlaneUid
Sourceimpl PartialOrd for TrackPlaneUid
impl PartialOrd for TrackPlaneUid
impl Copy for TrackPlaneUid
impl Eq for TrackPlaneUid
impl StructuralPartialEq for TrackPlaneUid