pub struct TrackTranslate {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub track_translate_track_id: TrackTranslateTrackId,
pub track_translate_codec: TrackTranslateCodec,
pub track_translate_edition_uid: Vec<TrackTranslateEditionUid>,
}Expand description
The mapping between this TrackEntry and a track value in the given Chapter Codec. Chapter Codec may need to address content in specific track, but they may not know of the way to identify tracks in Matroska. This element and its child elements add a way to map the internal tracks known to the Chapter Codec to the track IDs in Matroska. This allows remuxing a file with Chapter Codec without changing the content of the codec data, just the track mapping.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
track_translate_track_id: TrackTranslateTrackIdThe binary value used to represent this TrackEntry in the chapter codec data. The format depends on the ChapProcessCodecID used; see ChapProcessCodecID.
track_translate_codec: TrackTranslateCodecThis TrackTranslate applies to this chapter codec of the given chapter edition(s); see ChapProcessCodecID.
- 0 - Matroska Script,
- 1 - DVD-menu
track_translate_edition_uid: Vec<TrackTranslateEditionUid>Specify a chapter edition UID on which this TrackTranslate applies. When no TrackTranslateEditionUID is specified in the TrackTranslate, the TrackTranslate applies to all chapter editions found in the Segment using the given TrackTranslateCodec.