pub struct TrackTranslateCodec(pub u64);Expand description
Applies to the chapter codec of the given chapter edition(s); see (#chapprocesscodecid-element).
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackTranslateCodec
impl Clone for TrackTranslateCodec
Sourcefn clone(&self) -> TrackTranslateCodec
fn clone(&self) -> TrackTranslateCodec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackTranslateCodec
impl Debug for TrackTranslateCodec
Sourceimpl Default for TrackTranslateCodec
impl Default for TrackTranslateCodec
Sourceimpl Deref for TrackTranslateCodec
impl Deref for TrackTranslateCodec
Sourceimpl Element for TrackTranslateCodec
impl Element for TrackTranslateCodec
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackTranslateCodec
impl Hash for TrackTranslateCodec
Sourceimpl Ord for TrackTranslateCodec
impl Ord for TrackTranslateCodec
Sourcefn cmp(&self, other: &TrackTranslateCodec) -> Ordering
fn cmp(&self, other: &TrackTranslateCodec) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackTranslateCodec
impl PartialEq for TrackTranslateCodec
Sourceimpl PartialOrd for TrackTranslateCodec
impl PartialOrd for TrackTranslateCodec
impl Copy for TrackTranslateCodec
impl Eq for TrackTranslateCodec
impl StructuralPartialEq for TrackTranslateCodec