pub struct TrackTranslateEditionUid(pub u64);Expand description
Specifies a chapter edition UID to which this TrackTranslate applies.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrackTranslateEditionUid
impl Clone for TrackTranslateEditionUid
Sourcefn clone(&self) -> TrackTranslateEditionUid
fn clone(&self) -> TrackTranslateEditionUid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackTranslateEditionUid
impl Debug for TrackTranslateEditionUid
Sourceimpl Default for TrackTranslateEditionUid
impl Default for TrackTranslateEditionUid
Sourceimpl Deref for TrackTranslateEditionUid
impl Deref for TrackTranslateEditionUid
Sourceimpl Element for TrackTranslateEditionUid
impl Element for TrackTranslateEditionUid
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrackTranslateEditionUid
impl Hash for TrackTranslateEditionUid
Sourceimpl Ord for TrackTranslateEditionUid
impl Ord for TrackTranslateEditionUid
Sourcefn cmp(&self, other: &TrackTranslateEditionUid) -> Ordering
fn cmp(&self, other: &TrackTranslateEditionUid) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackTranslateEditionUid
impl PartialEq for TrackTranslateEditionUid
Sourceimpl PartialOrd for TrackTranslateEditionUid
impl PartialOrd for TrackTranslateEditionUid
impl Copy for TrackTranslateEditionUid
impl Eq for TrackTranslateEditionUid
impl StructuralPartialEq for TrackTranslateEditionUid