pub struct TrackType(pub u64);Expand description
The TrackType defines the type of each frame found in the Track.
The value SHOULD be stored on 1 octet.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for TrackType
impl Element for TrackType
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for TrackType
impl Ord for TrackType
Sourceimpl PartialOrd for TrackType
impl PartialOrd for TrackType
impl Copy for TrackType
impl Eq for TrackType
impl StructuralPartialEq for TrackType