pub struct TransferCharacteristics(pub u64);Expand description
The transfer characteristics of the video. For clarity,
the value and meanings for TransferCharacteristics are adopted from Table 3 of [@!ITU-H.273].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TransferCharacteristics
impl Clone for TransferCharacteristics
Sourcefn clone(&self) -> TransferCharacteristics
fn clone(&self) -> TransferCharacteristics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferCharacteristics
impl Debug for TransferCharacteristics
Sourceimpl Default for TransferCharacteristics
impl Default for TransferCharacteristics
Sourceimpl Deref for TransferCharacteristics
impl Deref for TransferCharacteristics
Sourceimpl Element for TransferCharacteristics
impl Element for TransferCharacteristics
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TransferCharacteristics
impl Hash for TransferCharacteristics
Sourceimpl Ord for TransferCharacteristics
impl Ord for TransferCharacteristics
Sourcefn cmp(&self, other: &TransferCharacteristics) -> Ordering
fn cmp(&self, other: &TransferCharacteristics) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TransferCharacteristics
impl PartialEq for TransferCharacteristics
Sourceimpl PartialOrd for TransferCharacteristics
impl PartialOrd for TransferCharacteristics
impl Copy for TransferCharacteristics
impl Eq for TransferCharacteristics
impl StructuralPartialEq for TransferCharacteristics