pub struct TrickTrackFlag(pub u64);Expand description
Set to 1 if this video track is a Smooth FF/RW track. If set to 1, MasterTrackUID and MasterTrackSegUID should be present, and
BlockGroups for this track must contain ReferenceFrame structures.
Otherwise, TrickTrackUID and TrickTrackSegUID must be present if this track has a corresponding Smooth FF/RW track. See [@?DivXTrickTrack].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrickTrackFlag
impl Clone for TrickTrackFlag
Sourcefn clone(&self) -> TrickTrackFlag
fn clone(&self) -> TrickTrackFlag
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrickTrackFlag
impl Debug for TrickTrackFlag
Sourceimpl Default for TrickTrackFlag
impl Default for TrickTrackFlag
Sourceimpl Deref for TrickTrackFlag
impl Deref for TrickTrackFlag
Sourceimpl Element for TrickTrackFlag
impl Element for TrickTrackFlag
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrickTrackFlag
impl Hash for TrickTrackFlag
Sourceimpl Ord for TrickTrackFlag
impl Ord for TrickTrackFlag
Sourcefn cmp(&self, other: &TrickTrackFlag) -> Ordering
fn cmp(&self, other: &TrickTrackFlag) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrickTrackFlag
impl PartialEq for TrickTrackFlag
Sourceimpl PartialOrd for TrickTrackFlag
impl PartialOrd for TrickTrackFlag
impl Copy for TrickTrackFlag
impl Eq for TrickTrackFlag
impl StructuralPartialEq for TrickTrackFlag