pub struct TrickTrackUID(pub u64);Expand description
The TrackUID of the Smooth FF/RW video in the paired EBML structure corresponding to this video track. See [@?DivXTrickTrack].
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TrickTrackUID
impl Clone for TrickTrackUID
Sourcefn clone(&self) -> TrickTrackUID
fn clone(&self) -> TrickTrackUID
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrickTrackUID
impl Debug for TrickTrackUID
Sourceimpl Default for TrickTrackUID
impl Default for TrickTrackUID
Sourceimpl Deref for TrickTrackUID
impl Deref for TrickTrackUID
Sourceimpl Element for TrickTrackUID
impl Element for TrickTrackUID
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for TrickTrackUID
impl Hash for TrickTrackUID
Sourceimpl Ord for TrickTrackUID
impl Ord for TrickTrackUID
Sourcefn cmp(&self, other: &TrickTrackUID) -> Ordering
fn cmp(&self, other: &TrickTrackUID) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrickTrackUID
impl PartialEq for TrickTrackUID
Sourceimpl PartialOrd for TrickTrackUID
impl PartialOrd for TrickTrackUID
impl Copy for TrickTrackUID
impl Eq for TrickTrackUID
impl StructuralPartialEq for TrickTrackUID