pub struct Video {Show 18 fields
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub flag_interlaced: FlagInterlaced,
pub field_order: FieldOrder,
pub stereo_mode: StereoMode,
pub alpha_mode: AlphaMode,
pub pixel_width: PixelWidth,
pub pixel_height: PixelHeight,
pub pixel_crop_bottom: PixelCropBottom,
pub pixel_crop_top: PixelCropTop,
pub pixel_crop_left: PixelCropLeft,
pub pixel_crop_right: PixelCropRight,
pub display_width: Option<DisplayWidth>,
pub display_height: Option<DisplayHeight>,
pub display_unit: DisplayUnit,
pub uncompressed_fourcc: Option<UncompressedFourcc>,
pub colour: Option<Colour>,
pub projection: Option<Projection>,
}Expand description
Video settings.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
flag_interlaced: FlagInterlacedSpecify whether the video frames in this track are interlaced.
- 0 - undetermined,
- 1 - interlaced,
- 2 - progressive
field_order: FieldOrderSpecify the field ordering of video frames in this track. If FlagInterlaced is not set to 1, this Element MUST be ignored.
- 0 - progressive,
- 1 - tff,
- 2 - undetermined,
- 6 - bff,
- 9 - bff(swapped),
- 14 - tff(swapped)
stereo_mode: StereoModeStereo-3D video mode. There are some more details in notes.
- 0 - mono,
- 1 - side by side (left eye first),
- 2 - top - bottom (right eye is first),
- 3 - top - bottom (left eye is first),
- 4 - checkboard (right eye is first),
- 5 - checkboard (left eye is first),
- 6 - row interleaved (right eye is first),
- 7 - row interleaved (left eye is first),
- 8 - column interleaved (right eye is first),
- 9 - column interleaved (left eye is first),
- 10 - anaglyph (cyan/red),
- 11 - side by side (right eye first),
- 12 - anaglyph (green/magenta),
- 13 - both eyes laced in one Block (left eye is first),
- 14 - both eyes laced in one Block (right eye is first)
alpha_mode: AlphaModeIndicate whether the BlockAdditional Element with BlockAddID of “1” contains Alpha data, as defined by to the Codec Mapping for the CodecID. Undefined values SHOULD NOT be used as the behavior of known implementations is different (considered either as 0 or 1).
- 0 - none,
- 1 - present
pixel_width: PixelWidthWidth of the encoded video frames in pixels.
pixel_height: PixelHeightHeight of the encoded video frames in pixels.
pixel_crop_bottom: PixelCropBottomThe number of video pixels to remove at the bottom of the image.
pixel_crop_top: PixelCropTopThe number of video pixels to remove at the top of the image.
pixel_crop_left: PixelCropLeftThe number of video pixels to remove on the left of the image.
pixel_crop_right: PixelCropRightThe number of video pixels to remove on the right of the image.
display_width: Option<DisplayWidth>Width of the video frames to display. Applies to the video frame after cropping (PixelCrop* Elements). If the DisplayUnit of the same TrackEntry is 0, then the default value for DisplayWidth is equal to PixelWidth - PixelCropLeft - PixelCropRight, else there is no default value.
display_height: Option<DisplayHeight>Height of the video frames to display. Applies to the video frame after cropping (PixelCrop* Elements). If the DisplayUnit of the same TrackEntry is 0, then the default value for DisplayHeight is equal to PixelHeight - PixelCropTop - PixelCropBottom, else there is no default value.
display_unit: DisplayUnitHow DisplayWidth & DisplayHeight are interpreted.
- 0 - pixels,
- 1 - centimeters,
- 2 - inches,
- 3 - display aspect ratio,
- 4 - unknown
uncompressed_fourcc: Option<UncompressedFourcc>Specify the uncompressed pixel format used for the Track’s data as a FourCC. This value is similar in scope to the biCompression value of AVI’s BITMAPINFO [@?AVIFormat]. There is no definitive list of FourCC values, nor an official registry. Some common values for YUV pixel formats can be found at [@?MSYUV8], [@?MSYUV16] and [@?FourCC-YUV]. Some common values for uncompressed RGB pixel formats can be found at [@?MSRGB] and [@?FourCC-RGB]. UncompressedFourCC MUST be set in TrackEntry, when the CodecID Element of the TrackEntry is set to “V_UNCOMPRESSED”.
colour: Option<Colour>Settings describing the colour format.
projection: Option<Projection>Describes the video projection details. Used to render spherical, VR videos or flipping videos horizontally/vertically.