pub struct SegmentView {
pub seek_head: Vec<SeekHead>,
pub info: Info,
pub tracks: Option<Tracks>,
pub cues: Option<Cues>,
pub attachments: Option<Attachments>,
pub chapters: Option<Chapters>,
pub tags: Vec<Tags>,
pub segment_data_position: u64,
pub first_cluster_position: u64,
}utils only.Expand description
View of a Segment, parsing the Segment header, but not loading Clusters.
Fields
seek_head: Vec<SeekHead>Contains seeking information of Top-Level Elements; see data-layout.
info: InfoContains general information about the Segment.
tracks: Option<Tracks>A Top-Level Element of information with many tracks described.
cues: Option<Cues>A Top-Level Element to speed seeking access. All entries are local to the Segment. This Element SHOULD be set when the Segment is not transmitted as a live stream (see #livestreaming).
attachments: Option<Attachments>Contain attached files.
chapters: Option<Chapters>A system to define basic menus and partition data. For more detailed information, look at the Chapters explanation in chapters.
Element containing metadata describing Tracks, Editions, Chapters, Attachments, or the Segment as a whole. A list of valid tags can be found in Matroska tagging RFC.
segment_data_position: u64The position of the Segment data (after the Segment header).
first_cluster_position: u64The position of the first Cluster in the Segment. 0 if no Cluster found.
Implementations