pub struct BitDepth(pub u64);Expand description
Bits per sample, mostly used for PCM.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for BitDepth
impl Element for BitDepth
Sourcefn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
fn decode_body<B: Buf>(buf: &mut B) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for BitDepth
impl Ord for BitDepth
Sourceimpl PartialOrd for BitDepth
impl PartialOrd for BitDepth
impl Copy for BitDepth
impl Eq for BitDepth
impl StructuralPartialEq for BitDepth