pub struct ChapterAtom {Show 16 fields
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub chapter_uid: ChapterUid,
pub chapter_string_uid: Option<ChapterStringUid>,
pub chapter_time_start: ChapterTimeStart,
pub chapter_time_end: Option<ChapterTimeEnd>,
pub chapter_flag_hidden: ChapterFlagHidden,
pub chapter_flag_enabled: ChapterFlagEnabled,
pub chapter_segment_uuid: Option<ChapterSegmentUuid>,
pub chapter_skip_type: Option<ChapterSkipType>,
pub chapter_segment_edition_uid: Option<ChapterSegmentEditionUid>,
pub chapter_physical_equiv: Option<ChapterPhysicalEquiv>,
pub chapter_track: Option<ChapterTrack>,
pub chapter_display: Vec<ChapterDisplay>,
pub chap_process: Vec<ChapProcess>,
pub chapter_atom: Vec<ChapterAtom>,
}Expand description
Contains the atom information to use as the chapter atom (apply to all tracks).
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
chapter_uid: ChapterUidContains the atom information to use as the chapter atom (apply to all tracks).
chapter_string_uid: Option<ChapterStringUid>A unique string ID to identify the Chapter. For example it is used as the storage for [@?WebVTT] cue identifier values.
chapter_time_start: ChapterTimeStartTimestamp of the start of Chapter, expressed in Matroska Ticks – i.e., in nanoseconds; see timestamp-ticks.
chapter_time_end: Option<ChapterTimeEnd>Timestamp of the end of Chapter timestamp excluded, expressed in Matroska Ticks – i.e., in nanoseconds; see timestamp-ticks. The value MUST be greater than or equal to the ChapterTimeStart of the same ChapterAtom. The ChapterTimeEnd timestamp value being excluded, it MUST take in account the duration of the last frame it includes, especially for the ChapterAtom using the last frames of the Segment. ChapterTimeEnd MUST be set if the Edition is an ordered edition; see (#editionflagordered), unless it’s a Parent Chapter; see (#nested-chapters)
Set to 1 if a chapter is hidden. Hidden chapters SHOULD NOT be available to the user interface (but still to Control Tracks; see chapterflaghidden on Chapter flags).
chapter_flag_enabled: ChapterFlagEnabledSet to 1 if the chapter is enabled. It can be enabled/disabled by a Control Track. When disabled, the movie SHOULD skip all the content between the TimeStart and TimeEnd of this chapter; see notes on Chapter flags.
chapter_segment_uuid: Option<ChapterSegmentUuid>The SegmentUUID of another Segment to play during this chapter. The value MUST NOT be the SegmentUUID value of the Segment it belongs to. ChapterSegmentUUID MUST be set if ChapterSegmentEditionUID is used; see (#medium-linking) on medium-linking Segments.
chapter_skip_type: Option<ChapterSkipType>Indicate what type of content the ChapterAtom contains and might be skipped. It can be used to automatically skip content based on the type. If a ChapterAtom is inside a ChapterAtom that has a ChapterSkipType set, it MUST NOT have a ChapterSkipType or have a ChapterSkipType with the same value as it’s parent ChapterAtom. If the ChapterAtom doesn’t contain a ChapterTimeEnd, the value of the ChapterSkipType is only valid until the next ChapterAtom with a ChapterSkipType value or the end of the file.
- 0 - No Skipping,
- 1 - Opening Credits,
- 2 - End Credits,
- 3 - Recap,
- 4 - Next Preview,
- 5 - Preview,
- 6 - Advertisement
chapter_segment_edition_uid: Option<ChapterSegmentEditionUid>The EditionUID to play from the Segment linked in ChapterSegmentUUID. If ChapterSegmentEditionUID is undeclared, then no Edition of the linked Segment is used; see medium-linking on medium-linking Segments.
chapter_physical_equiv: Option<ChapterPhysicalEquiv>Specify the physical equivalent of this ChapterAtom like “DVD” (60) or “SIDE” (50); see notes for a complete list of values.
chapter_track: Option<ChapterTrack>List of tracks on which the chapter applies. If this Element is not present, all tracks apply
chapter_display: Vec<ChapterDisplay>Contains all possible strings to use for the chapter display.
chap_process: Vec<ChapProcess>Contains all the commands associated to the Atom.
chapter_atom: Vec<ChapterAtom>Contains nested ChapterAtoms, used when chapter have sub-chapters or sub-sections