pub struct ChapterDisplay {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub chap_string: ChapString,
pub chap_language: Vec<ChapLanguage>,
pub chap_language_bcp47: Vec<ChapLanguageBcp47>,
pub chap_country: Vec<ChapCountry>,
}Expand description
Contains all possible strings to use for the chapter display.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
chap_string: ChapStringContains the string to use as the chapter atom.
chap_language: Vec<ChapLanguage>A language corresponding to the string, in the Matroska languages form; see basics on language codes. This Element MUST be ignored if a ChapLanguageBCP47 Element is used within the same ChapterDisplay Element.
chap_language_bcp47: Vec<ChapLanguageBcp47>A language corresponding to the ChapString, in the [@!BCP47] form; see basics on language codes. If a ChapLanguageBCP47 Element is used, then any ChapLanguage and ChapCountry Elements used in the same ChapterDisplay MUST be ignored.
chap_country: Vec<ChapCountry>A country corresponding to the string, in the Matroska countries form; see basics on country codes. This Element MUST be ignored if a ChapLanguageBCP47 Element is used within the same ChapterDisplay Element.