pub struct Colour {Show 16 fields
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub matrix_coefficients: MatrixCoefficients,
pub bits_per_channel: BitsPerChannel,
pub chroma_subsampling_horz: Option<ChromaSubsamplingHorz>,
pub chroma_subsampling_vert: Option<ChromaSubsamplingVert>,
pub cb_subsampling_horz: Option<CbSubsamplingHorz>,
pub cb_subsampling_vert: Option<CbSubsamplingVert>,
pub chroma_siting_horz: ChromaSitingHorz,
pub chroma_siting_vert: ChromaSitingVert,
pub range: Range,
pub transfer_characteristics: TransferCharacteristics,
pub primaries: Primaries,
pub max_cll: Option<MaxCll>,
pub max_fall: Option<MaxFall>,
pub mastering_metadata: Option<MasteringMetadata>,
}Expand description
Settings describing the colour format.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
matrix_coefficients: MatrixCoefficientsThe Matrix Coefficients of the video used to derive luma and chroma values from red, green, and blue color primaries. For clarity, the value and meanings for MatrixCoefficients are adopted from Table 4 of ISO/IEC 23001-8:2016 or ITU-T H.273.
- 0 - Identity,
- 1 - ITU-R BT.709,
- 2 - unspecified,
- 3 - reserved,
- 4 - US FCC 73.682,
- 5 - ITU-R BT.470BG,
- 6 - SMPTE 170M,
- 7 - SMPTE 240M,
- 8 - YCoCg,
- 9 - BT2020 Non-constant Luminance,
- 10 - BT2020 Constant Luminance,
- 11 - SMPTE ST 2085,
- 12 - Chroma-derived Non-constant Luminance,
- 13 - Chroma-derived Constant Luminance,
- 14 - ITU-R BT.2100-0
bits_per_channel: BitsPerChannelNumber of decoded bits per channel. A value of 0 indicates that the BitsPerChannel is unspecified.
chroma_subsampling_horz: Option<ChromaSubsamplingHorz>The amount of pixels to remove in the Cr and Cb channels for every pixel not removed horizontally. Example: For video with 4:2:0 chroma subsampling, the ChromaSubsamplingHorz SHOULD be set to 1.
chroma_subsampling_vert: Option<ChromaSubsamplingVert>The amount of pixels to remove in the Cr and Cb channels for every pixel not removed vertically. Example: For video with 4:2:0 chroma subsampling, the ChromaSubsamplingVert SHOULD be set to 1.
cb_subsampling_horz: Option<CbSubsamplingHorz>The amount of pixels to remove in the Cb channel for every pixel not removed horizontally. This is additive with ChromaSubsamplingHorz. Example: For video with 4:2:1 chroma subsampling, the ChromaSubsamplingHorz SHOULD be set to 1 and CbSubsamplingHorz SHOULD be set to 1.
cb_subsampling_vert: Option<CbSubsamplingVert>The amount of pixels to remove in the Cb channel for every pixel not removed vertically. This is additive with ChromaSubsamplingVert.
chroma_siting_horz: ChromaSitingHorzHow chroma is subsampled horizontally.
- 0 - unspecified,
- 1 - left collocated,
- 2 - half
chroma_siting_vert: ChromaSitingVertHow chroma is subsampled vertically.
- 0 - unspecified,
- 1 - top collocated,
- 2 - half
range: RangeClipping of the color ranges.
- 0 - unspecified,
- 1 - broadcast range,
- 2 - full range (no clipping),
- 3 - defined by MatrixCoefficients / TransferCharacteristics
transfer_characteristics: TransferCharacteristicsThe transfer characteristics of the video. For clarity, the value and meanings for TransferCharacteristics are adopted from Table 3 of ISO/IEC 23091-4 or ITU-T H.273.
- 0 - reserved,
- 1 - ITU-R BT.709,
- 2 - unspecified,
- 3 - reserved2,
- 4 - Gamma 2.2 curve - BT.470M,
- 5 - Gamma 2.8 curve - BT.470BG,
- 6 - SMPTE 170M,
- 7 - SMPTE 240M,
- 8 - Linear,
- 9 - Log,
- 10 - Log Sqrt,
- 11 - IEC 61966-2-4,
- 12 - ITU-R BT.1361 Extended Colour Gamut,
- 13 - IEC 61966-2-1,
- 14 - ITU-R BT.2020 10 bit,
- 15 - ITU-R BT.2020 12 bit,
- 16 - ITU-R BT.2100 Perceptual Quantization,
- 17 - SMPTE ST 428-1,
- 18 - ARIB STD-B67 (HLG)
primaries: PrimariesThe colour primaries of the video. For clarity, the value and meanings for Primaries are adopted from Table 2 of ISO/IEC 23091-4 or ITU-T H.273.
- 0 - reserved,
- 1 - ITU-R BT.709,
- 2 - unspecified,
- 3 - reserved2,
- 4 - ITU-R BT.470M,
- 5 - ITU-R BT.470BG - BT.601 625,
- 6 - ITU-R BT.601 525 - SMPTE 170M,
- 7 - SMPTE 240M,
- 8 - FILM,
- 9 - ITU-R BT.2020,
- 10 - SMPTE ST 428-1,
- 11 - SMPTE RP 432-2,
- 12 - SMPTE EG 432-2,
- 22 - EBU Tech. 3213-E - JEDEC P22 phosphors
max_cll: Option<MaxCll>Maximum brightness of a single pixel (Maximum Content Light Level) in candelas per square meter (cd/m^2^).
max_fall: Option<MaxFall>Maximum brightness of a single full frame (Maximum Frame-Average Light Level) in candelas per square meter (cd/m^2^).
mastering_metadata: Option<MasteringMetadata>SMPTE 2086 mastering data.