pub struct Emphasis(pub u64);Expand description
Audio emphasis applied on audio samples. The player MUST apply the inverse emphasis to get the proper audio samples.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for Emphasis
impl Element for Emphasis
Sourceconst HAS_DEFAULT_VALUE: bool = true
const HAS_DEFAULT_VALUE: bool = true
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for Emphasis
impl Ord for Emphasis
Sourceimpl PartialOrd for Emphasis
impl PartialOrd for Emphasis
impl Copy for Emphasis
impl Eq for Emphasis
impl StructuralPartialEq for Emphasis