pub struct FileUid(pub u64);Expand description
UID representing the file, as random as possible.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for FileUid
impl Element for FileUid
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for FileUid
impl Ord for FileUid
Sourceimpl PartialOrd for FileUid
impl PartialOrd for FileUid
impl Copy for FileUid
impl Eq for FileUid
impl StructuralPartialEq for FileUid