pub struct MaxCache(pub u64);Expand description
The maximum cache size necessary to store referenced frames in and the current frame. 0 means no cache is needed.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Element for MaxCache
impl Element for MaxCache
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Ord for MaxCache
impl Ord for MaxCache
Sourceimpl PartialOrd for MaxCache
impl PartialOrd for MaxCache
impl Copy for MaxCache
impl Eq for MaxCache
impl StructuralPartialEq for MaxCache