A timestamp value, relative to the timestamp of the Block in this BlockGroup, expressed in Track Ticks; see (#timestamp-ticks).
This is used to reference other frames necessary to decode this frame.
The relative value SHOULD correspond to a valid Block that this Block depends on.
Historically, Matroska Writers didn’t write the actual Block(s) that this Block depends on, but they did write someBlock(s) in the past.
The value “0” MAY also be used to signify that this Block cannot be decoded on its own, but the necessary reference Block(s) is unknown. In this case, other ReferenceBlock elements MUST NOT be found in the same BlockGroup. If the BlockGroup doesn’t have a ReferenceBlock element, then the Block it contains can be decoded without using any other Block data.
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.