pub struct ReferenceVirtual(pub i64);Expand description
The Segment Position of the data that would otherwise be in position of the virtual block.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for ReferenceVirtual
impl Clone for ReferenceVirtual
Sourcefn clone(&self) -> ReferenceVirtual
fn clone(&self) -> ReferenceVirtual
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReferenceVirtual
impl Debug for ReferenceVirtual
Sourceimpl Default for ReferenceVirtual
impl Default for ReferenceVirtual
Sourceimpl Deref for ReferenceVirtual
impl Deref for ReferenceVirtual
Sourceimpl Element for ReferenceVirtual
impl Element for ReferenceVirtual
Sourcefn decode_body(buf: &mut &[u8]) -> Result<Self>
fn decode_body(buf: &mut &[u8]) -> Result<Self>
Decode the body of the element from a buffer.
Sourcefn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
fn encode_body<B: BufMut>(&self, buf: &mut B) -> Result<()>
Encode the body of the element to a buffer.
Sourceconst HAS_DEFAULT_VALUE: bool = false
const HAS_DEFAULT_VALUE: bool = false
Whether the element has a default value, as per Matroska specification.
If true, and the element is missing in a master element, it should be treated as if it were present with the default value.
If false, and the element is missing in a master element, it should be treated as an error.
Sourceimpl Hash for ReferenceVirtual
impl Hash for ReferenceVirtual
Sourceimpl Ord for ReferenceVirtual
impl Ord for ReferenceVirtual
Sourcefn cmp(&self, other: &ReferenceVirtual) -> Ordering
fn cmp(&self, other: &ReferenceVirtual) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReferenceVirtual
impl PartialEq for ReferenceVirtual
Sourceimpl PartialOrd for ReferenceVirtual
impl PartialOrd for ReferenceVirtual
impl Copy for ReferenceVirtual
impl Eq for ReferenceVirtual
impl StructuralPartialEq for ReferenceVirtual