pub struct Segment {
pub crc32: Option<Crc32>,
pub void: Option<Void>,
pub seek_head: Vec<SeekHead>,
pub info: Info,
pub cluster: Vec<Cluster>,
pub tracks: Option<Tracks>,
pub cues: Option<Cues>,
pub attachments: Option<Attachments>,
pub chapters: Option<Chapters>,
pub tags: Vec<Tags>,
}Expand description
The Root Element that contains all other Top-Level Elements; see data-layout.
Fields
crc32: Option<Crc32>Optional CRC-32 element for integrity checking.
void: Option<Void>void element, useful for reserving space during writing.
seek_head: Vec<SeekHead>Contains seeking information of Top-Level Elements; see data-layout.
info: InfoContains general information about the Segment.
cluster: Vec<Cluster>The Top-Level Element containing the (monolithic) Block structure.
tracks: Option<Tracks>A Top-Level Element of information with many tracks described.
cues: Option<Cues>A Top-Level Element to speed seeking access. All entries are local to the Segment. This Element SHOULD be set when the Segment is not transmitted as a live stream (see #livestreaming).
attachments: Option<Attachments>Contain attached files.
chapters: Option<Chapters>A system to define basic menus and partition data. For more detailed information, look at the Chapters explanation in chapters.
Element containing metadata describing Tracks, Editions, Chapters, Attachments, or the Segment as a whole. A list of valid tags can be found in Matroska tagging RFC.