SimpleTag

Struct SimpleTag 

pub struct SimpleTag {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub tag_name: TagName,
    pub tag_language: TagLanguage,
    pub tag_language_bcp47: Option<TagLanguageBcp47>,
    pub tag_default: TagDefault,
    pub tag_string: Option<TagString>,
    pub tag_binary: Option<TagBinary>,
    pub simple_tag: Vec<SimpleTag>,
}
Contains general information about the target.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

tag_name: TagName

The name of the Tag that is going to be stored.

tag_language: TagLanguage

Specifies the language of the tag specified, in the Matroska languages form; see basics on language codes. This Element MUST be ignored if the TagLanguageBCP47 Element is used within the same SimpleTag Element.

tag_language_bcp47: Option<TagLanguageBcp47>

The language used in the TagString, in the [@!BCP47] form; see basics on language codes. If this Element is used, then any TagLanguage Elements used in the same SimpleTag MUST be ignored.

tag_default: TagDefault

A boolean value to indicate if this is the default/original language to use for the given tag.

tag_string: Option<TagString>

The value of the Tag.

tag_binary: Option<TagBinary>

The values of the Tag, if it is binary. Note that this cannot be used in the same SimpleTag as TagString.

simple_tag: Vec<SimpleTag>

Nested simple tags, if any.