Targets

Struct Targets 

pub struct Targets {
    pub crc32: Option<Crc32>,
    pub void: Option<Void>,
    pub target_type_value: TargetTypeValue,
    pub target_type: Option<TargetType>,
    pub tag_track_uid: Vec<TagTrackUid>,
    pub tag_edition_uid: Vec<TagEditionUid>,
    pub tag_chapter_uid: Vec<TagChapterUid>,
    pub tag_attachment_uid: Vec<TagAttachmentUid>,
}
Specifies which other elements the metadata represented by the Tag applies to. If empty or omitted, then the Tag describes everything in the Segment.

Fields

crc32: Option<Crc32>

Optional CRC-32 element for integrity checking.

void: Option<Void>

void element, useful for reserving space during writing.

target_type_value: TargetTypeValue

A number to indicate the logical level of the target.

  • 70 - COLLECTION,
  • 60 - EDITION / ISSUE / VOLUME / OPUS / SEASON / SEQUEL,
  • 50 - ALBUM / OPERA / CONCERT / MOVIE / EPISODE,
  • 40 - PART / SESSION,
  • 30 - TRACK / SONG / CHAPTER,
  • 20 - SUBTRACK / MOVEMENT / SCENE,
  • 10 - SHOT
target_type: Option<TargetType>

An informational string that can be used to display the logical level of the target like “ALBUM”, “TRACK”, “MOVIE”, “CHAPTER”, etc. ; see Section 6.4 of Matroska tagging RFC.

  • COLLECTION - TargetTypeValue 70,
  • EDITION - TargetTypeValue 60,
  • ISSUE - TargetTypeValue 60,
  • VOLUME - TargetTypeValue 60,
  • OPUS - TargetTypeValue 60,
  • SEASON - TargetTypeValue 60,
  • SEQUEL - TargetTypeValue 60,
  • ALBUM - TargetTypeValue 50,
  • OPERA - TargetTypeValue 50,
  • CONCERT - TargetTypeValue 50,
  • MOVIE - TargetTypeValue 50,
  • EPISODE - TargetTypeValue 50,
  • PART - TargetTypeValue 40,
  • SESSION - TargetTypeValue 40,
  • TRACK - TargetTypeValue 30,
  • SONG - TargetTypeValue 30,
  • CHAPTER - TargetTypeValue 30,
  • SUBTRACK - TargetTypeValue 20,
  • MOVEMENT - TargetTypeValue 20,
  • SCENE - TargetTypeValue 20,
  • SHOT - TargetTypeValue 10
tag_track_uid: Vec<TagTrackUid>

A unique ID to identify the Track(s) the tags belong to. If the value is 0 at this level, the tags apply to all tracks in the Segment. If set to any other value, it MUST match the TrackUID value of a track found in this Segment.

tag_edition_uid: Vec<TagEditionUid>

A unique ID to identify the EditionEntry(s) the tags belong to. If the value is 0 at this level, the tags apply to all editions in the Segment. If set to any other value, it MUST match the EditionUID value of an edition found in this Segment.

tag_chapter_uid: Vec<TagChapterUid>

A unique ID to identify the Chapter(s) the tags belong to. If the value is 0 at this level, the tags apply to all chapters in the Segment. If set to any other value, it MUST match the ChapterUID value of a chapter found in this Segment.

tag_attachment_uid: Vec<TagAttachmentUid>

A unique ID to identify the Attachment(s) the tags belong to. If the value is 0 at this level, the tags apply to all the attachments in the Segment. If set to any other value, it MUST match the FileUID value of an attachment found in this Segment.